@@ -2,6 +2,6 @@
 set -Eeuo pipefail
 
 bin/install_rust.sh
-pip3 install -r bin/requirements-frozen.txt
+python3 -m pip install --requirement bin/requirements-frozen.txt
 sudo apt-get update && sudo apt-get install -y libxml2-utils
 
