@@ -10,7 +10,7 @@ hurl --version
 hurlfmt --version
 
 # bench
-pip3 install --requirement bin/requirements-frozen.txt
+python3 -m pip install --requirement bin/requirements-frozen.txt
 cd bench
 python3 server.py > server.log 2>&1 &
 sleep 5
