@@ -28,7 +28,35 @@ function check_listen_port(){
         fi
         sleep 1
     done
-    echo "${exit_message}"
+    echo -e "\n${exit_message}"
+    return "${exit_code}"
+}
+
+function check_unix_socket(){
+    # vars
+    label="${1:-}"
+    socket_file="${2:-}"
+    path="${3:-}"
+
+    # usage
+    if [ -z "${label}" ] || [ -z "${socket_file}" ] ; then
+        echo "${color_red}Usage:${color_reset} check_unix_socket {label} {socket_file} {command}"
+        return 1
+    fi
+
+    for count in $(seq 30) ; do
+        if echo -e "${path}" | nc -U "${socket_file}" ; then
+            exit_message="${color_green}$(date) - ${label} listening${color_reset} on ${socket_file}"
+            exit_code=0
+            break
+        else
+            echo "$(date) - ${count} try - ${label} not listening${color_reset} on ${socket_file} yet"
+            exit_message="${color_red}$(date) - ${label} not listening${color_reset} on ${socket_file}"
+            exit_code=1
+        fi
+        sleep 1
+    done
+    echo -e "\n${exit_message}"
     return "${exit_code}"
 }
 
@@ -38,10 +66,10 @@ function cat_and_exit_err() {
     return 1
 }
 
-echo "----- install servers prerequisites -----"
+echo -e "\n----- install servers prerequisites -----"
 python3 -m pip install --requirement bin/requirements-frozen.txt
 
-echo "----- start servers -----"
+echo -e "\n----- start servers -----"
 cd integration/hurl
 mkdir -p build
 
@@ -58,11 +86,12 @@ python3 ssl/server.py 8002 ssl/server/cert.pem false > build/server-ssl-signedby
 check_listen_port "ssl/server.py" 8002 || cat_and_exit_err build/server-ssl-signedbyca.log
 
 echo -e "\n------------------ Starting ssl/server.py (Self-signed certificate + Client certificate authentication)"
-nohup python3 ssl/server.py 8003 ssl/server/cert.selfsigned.pem true > build/server-ssl-client-authent.log 2>&1 &
+python3 ssl/server.py 8003 ssl/server/cert.selfsigned.pem true > build/server-ssl-client-authent.log 2>&1 &
 check_listen_port "ssl/server.py" 8003 || cat_and_exit_err build/server-ssl-client-authent.log
 
 echo -e "\n------------------ Starting unix_socket/server.py"
 python3 unix_socket/server.py > build/server-unix-socket.log 2>&1 &
+check_unix_socket "unix_socket/server.py" build/unix_socket.sock "GET /hello HTTP/1.0\r\n"
 
 echo -e "\n------------------ Starting squid (proxy)"
 if [ -f /var/run/squid.pid ] ; then
@@ -73,3 +102,4 @@ fi
 squid_conf="cache deny all\ncache_log /dev/null\naccess_log /dev/null\nhttp_access allow all\nhttp_port 127.0.0.1:3128\nrequest_header_add From-Proxy Hello\nreply_header_add From-Proxy Hello"
 (echo -e "${squid_conf}" | sudo squid -d 2 -N -f /dev/stdin | sudo tee build/proxy.log 2>&1) &
 check_listen_port "squid" 3128 || cat_and_exit_err build/proxy.log
+
