@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -88,7 +88,7 @@ fn log_request(request: Request) {
                 for param in multipart_params {
                     match param {
                         MultipartParam::Param(value) => {
-                            eprintln!("\r{}: {}", value.key, value.value)
+                            eprintln!("\r{}: {}", value.key, value.value);
                         }
                         MultipartParam::FileParam(file_param) => {
                             let content_type =
