@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,15 +23,15 @@ use std::time::Duration;
 use std::{env, io};
 
 use clap::ArgMatches;
-use hurl::runner::Value;
+use hurl::runner::{Input, Value};
 use hurl_core::ast::Retry;
 
 use super::variables::{parse as parse_variable, parse_value};
-use super::OptionsError;
-use crate::cli::options::{ErrorFormat, HttpVersion, IpResolve};
+use super::CliOptionsError;
+use crate::cli::options::{ErrorFormat, HttpVersion, IpResolve, Output};
 use crate::cli::OutputType;
 
-pub fn cacert_file(arg_matches: &ArgMatches) -> Result<Option<String>, OptionsError> {
+pub fn cacert_file(arg_matches: &ArgMatches) -> Result<Option<String>, CliOptionsError> {
     match get_string(arg_matches, "cacert_file") {
         None => Ok(None),
         Some(filename) => {
@@ -39,7 +39,7 @@ pub fn cacert_file(arg_matches: &ArgMatches) -> Result<Option<String>, OptionsEr
             if path.exists() {
                 Ok(Some(filename))
             } else {
-                Err(OptionsError::Error(format!(
+                Err(CliOptionsError::Error(format!(
                     "input file {} does not exist",
                     path.display()
                 )))
@@ -52,13 +52,13 @@ pub fn aws_sigv4(arg_matches: &ArgMatches) -> Option<String> {
     get::<String>(arg_matches, "aws_sigv4")
 }
 
-pub fn client_cert_file(arg_matches: &ArgMatches) -> Result<Option<String>, OptionsError> {
+pub fn client_cert_file(arg_matches: &ArgMatches) -> Result<Option<String>, CliOptionsError> {
     match get::<String>(arg_matches, "client_cert_file") {
         None => Ok(None),
         Some(filename) => {
             if !Path::new(&filename).is_file() {
                 let message = format!("File {filename} does not exist");
-                Err(OptionsError::Error(message))
+                Err(CliOptionsError::Error(message))
             } else {
                 Ok(Some(filename))
             }
@@ -66,13 +66,13 @@ pub fn client_cert_file(arg_matches: &ArgMatches) -> Result<Option<String>, Opti
     }
 }
 
-pub fn client_key_file(arg_matches: &ArgMatches) -> Result<Option<String>, OptionsError> {
+pub fn client_key_file(arg_matches: &ArgMatches) -> Result<Option<String>, CliOptionsError> {
     match get::<String>(arg_matches, "client_key_file") {
         None => Ok(None),
         Some(filename) => {
             if !Path::new(&filename).is_file() {
                 let message = format!("File {filename} does not exist");
-                Err(OptionsError::Error(message))
+                Err(CliOptionsError::Error(message))
             } else {
                 Ok(Some(filename))
             }
@@ -121,8 +121,8 @@ pub fn cookie_input_file(arg_matches: &ArgMatches) -> Option<String> {
     get::<String>(arg_matches, "cookies_input_file")
 }
 
-pub fn cookie_output_file(arg_matches: &ArgMatches) -> Option<String> {
-    get::<String>(arg_matches, "cookies_output_file")
+pub fn cookie_output_file(arg_matches: &ArgMatches) -> Option<PathBuf> {
+    get::<String>(arg_matches, "cookies_output_file").map(PathBuf::from)
 }
 
 pub fn delay(arg_matches: &ArgMatches) -> Duration {
@@ -150,12 +150,16 @@ pub fn follow_location(arg_matches: &ArgMatches) -> (bool, bool) {
     (follow_location, follow_location_trusted)
 }
 
-pub fn html_dir(arg_matches: &ArgMatches) -> Result<Option<PathBuf>, OptionsError> {
+pub fn from_entry(arg_matches: &ArgMatches) -> Option<usize> {
+    get::<u32>(arg_matches, "from_entry").map(|x| x as usize)
+}
+
+pub fn html_dir(arg_matches: &ArgMatches) -> Result<Option<PathBuf>, CliOptionsError> {
     if let Some(dir) = get::<String>(arg_matches, "report_html") {
         let path = Path::new(&dir);
         if !path.exists() {
-            match std::fs::create_dir(path) {
-                Err(_) => Err(OptionsError::Error(format!(
+            match std::fs::create_dir_all(path) {
+                Err(_) => Err(CliOptionsError::Error(format!(
                     "HTML dir {} can not be created",
                     path.display()
                 ))),
@@ -164,7 +168,7 @@ pub fn html_dir(arg_matches: &ArgMatches) -> Result<Option<PathBuf>, OptionsErro
         } else if path.is_dir() {
             Ok(Some(path.to_path_buf()))
         } else {
-            return Err(OptionsError::Error(format!(
+            return Err(CliOptionsError::Error(format!(
                 "{} is not a valid directory",
                 path.display()
             )));
@@ -197,26 +201,22 @@ pub fn include(arg_matches: &ArgMatches) -> bool {
 }
 
 /// Returns the input files from the positional arguments and the glob options
-pub fn input_files(arg_matches: &ArgMatches) -> Result<Vec<String>, OptionsError> {
+pub fn input_files(arg_matches: &ArgMatches) -> Result<Vec<Input>, CliOptionsError> {
     let mut files = vec![];
     if let Some(filenames) = get_strings(arg_matches, "input_files") {
-        for filename in filenames {
-            let path = Path::new(&filename);
-            if path.exists() {
-                files.push(filename);
-            } else {
-                return Err(OptionsError::Error(format!(
-                    "hurl: cannot access '{}': No such file or directory",
-                    path.display()
-                )));
+        for filename in &filenames {
+            let file = Input::new(filename);
+            if !file.exists() {
+                return Err(CliOptionsError::InvalidInputFile(PathBuf::from(filename)));
             }
+            files.push(file);
         }
     }
     for filename in glob_files(arg_matches)? {
         files.push(filename);
     }
     if files.is_empty() && !io::stdin().is_terminal() {
-        files.push("-".to_string());
+        files.push(Input::Stdin);
     }
     Ok(files)
 }
@@ -239,8 +239,8 @@ pub fn ip_resolve(arg_matches: &ArgMatches) -> Option<IpResolve> {
     }
 }
 
-pub fn junit_file(arg_matches: &ArgMatches) -> Option<String> {
-    get::<String>(arg_matches, "report_junit")
+pub fn junit_file(arg_matches: &ArgMatches) -> Option<PathBuf> {
+    get::<String>(arg_matches, "report_junit").map(PathBuf::from)
 }
 
 pub fn max_redirect(arg_matches: &ArgMatches) -> Option<usize> {
@@ -250,12 +250,38 @@ pub fn max_redirect(arg_matches: &ArgMatches) -> Option<usize> {
     }
 }
 
+pub fn jobs(arg_matches: &ArgMatches) -> Option<usize> {
+    get::<u32>(arg_matches, "jobs").map(|m| m as usize)
+}
+
+pub fn netrc(arg_matches: &ArgMatches) -> bool {
+    has_flag(arg_matches, "netrc")
+}
+
+pub fn netrc_file(arg_matches: &ArgMatches) -> Result<Option<String>, CliOptionsError> {
+    match get::<String>(arg_matches, "netrc_file") {
+        None => Ok(None),
+        Some(filename) => {
+            if !Path::new(&filename).is_file() {
+                let message = format!("File {filename} does not exist");
+                Err(CliOptionsError::Error(message))
+            } else {
+                Ok(Some(filename))
+            }
+        }
+    }
+}
+
+pub fn netrc_optional(arg_matches: &ArgMatches) -> bool {
+    has_flag(arg_matches, "netrc_optional")
+}
+
 pub fn no_proxy(arg_matches: &ArgMatches) -> Option<String> {
     get::<String>(arg_matches, "noproxy")
 }
 
-pub fn output(arg_matches: &ArgMatches) -> Option<String> {
-    get::<String>(arg_matches, "output")
+pub fn output(arg_matches: &ArgMatches) -> Option<Output> {
+    get::<String>(arg_matches, "output").map(|filename| Output::new(&filename))
 }
 
 pub fn output_type(arg_matches: &ArgMatches) -> OutputType {
@@ -268,17 +294,16 @@ pub fn output_type(arg_matches: &ArgMatches) -> OutputType {
     }
 }
 
+pub fn parallel(arg_matches: &ArgMatches) -> bool {
+    has_flag(arg_matches, "parallel")
+}
+
 pub fn path_as_is(arg_matches: &ArgMatches) -> bool {
     has_flag(arg_matches, "path_as_is")
 }
 
 pub fn progress_bar(arg_matches: &ArgMatches) -> bool {
-    let verbose = verbose(arg_matches) || very_verbose(arg_matches);
-    test(arg_matches)
-        && !verbose
-        && !interactive(arg_matches)
-        && !is_ci()
-        && io::stderr().is_terminal()
+    test(arg_matches) && !interactive(arg_matches) && !is_ci() && io::stderr().is_terminal()
 }
 
 pub fn proxy(arg_matches: &ArgMatches) -> Option<String> {
@@ -306,8 +331,8 @@ pub fn ssl_no_revoke(arg_matches: &ArgMatches) -> bool {
     has_flag(arg_matches, "ssl_no_revoke")
 }
 
-pub fn tap_file(arg_matches: &ArgMatches) -> Option<String> {
-    get::<String>(arg_matches, "report_tap")
+pub fn tap_file(arg_matches: &ArgMatches) -> Option<PathBuf> {
+    get::<String>(arg_matches, "report_tap").map(PathBuf::from)
 }
 
 pub fn test(arg_matches: &ArgMatches) -> bool {
@@ -336,7 +361,7 @@ pub fn user_agent(arg_matches: &ArgMatches) -> Option<String> {
 }
 
 /// Returns a map of variables from the command line options `matches`.
-pub fn variables(matches: &ArgMatches) -> Result<HashMap<String, Value>, OptionsError> {
+pub fn variables(matches: &ArgMatches) -> Result<HashMap<String, Value>, CliOptionsError> {
     let mut variables = HashMap::new();
 
     // Use environment variables prefix by HURL_
@@ -351,7 +376,7 @@ pub fn variables(matches: &ArgMatches) -> Result<HashMap<String, Value>, Options
         for f in filenames.iter() {
             let path = Path::new(&f);
             if !path.exists() {
-                return Err(OptionsError::Error(format!(
+                return Err(CliOptionsError::Error(format!(
                     "Properties file {} does not exist",
                     path.display()
                 )));
@@ -363,7 +388,7 @@ pub fn variables(matches: &ArgMatches) -> Result<HashMap<String, Value>, Options
                 let line = match line {
                     Ok(s) => s,
                     Err(_) => {
-                        return Err(OptionsError::Error(format!(
+                        return Err(CliOptionsError::Error(format!(
                             "Can not parse line {} of {}",
                             index + 1,
                             path.display()
@@ -398,43 +423,41 @@ pub fn very_verbose(arg_matches: &ArgMatches) -> bool {
     has_flag(arg_matches, "very_verbose")
 }
 
+pub fn max_filesize(arg_matches: &ArgMatches) -> Option<u64> {
+    get::<u64>(arg_matches, "max_filesize")
+}
+
 /// Returns a list of path names from the command line options `matches`.
-fn glob_files(matches: &ArgMatches) -> Result<Vec<String>, OptionsError> {
-    let mut filenames = vec![];
+fn glob_files(matches: &ArgMatches) -> Result<Vec<Input>, CliOptionsError> {
+    let mut all_files = vec![];
     if let Some(exprs) = get_strings(matches, "glob") {
         for expr in exprs {
             let paths = match glob::glob(&expr) {
                 Ok(paths) => paths,
                 Err(_) => {
-                    return Err(OptionsError::Error(
+                    return Err(CliOptionsError::Error(
                         "Failed to read glob pattern".to_string(),
                     ))
                 }
             };
+            let mut files = vec![];
             for entry in paths {
                 match entry {
-                    Ok(path) => match path.into_os_string().into_string() {
-                        Ok(filename) => filenames.push(filename),
-                        Err(_) => {
-                            return Err(OptionsError::Error(
-                                "Failed to read glob pattern".to_string(),
-                            ))
-                        }
-                    },
+                    Ok(path) => files.push(Input::from(path)),
                     Err(_) => {
-                        return Err(OptionsError::Error(
+                        return Err(CliOptionsError::Error(
                             "Failed to read glob pattern".to_string(),
                         ))
                     }
                 }
             }
-            if filenames.is_empty() {
-                let message = format!("hurl: cannot access '{expr}': No such file or directory");
-                return Err(OptionsError::Error(message));
+            if files.is_empty() {
+                return Err(CliOptionsError::InvalidInputFile(PathBuf::from(&expr)));
             }
+            all_files.extend(files);
         }
     }
-    Ok(filenames)
+    Ok(all_files)
 }
 
 /// Returns an optional value of type `T` from the command line `matches` given the option `name`.
