@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
  *
  */
 mod commands;
+mod error;
 mod matches;
 mod variables;
 
@@ -27,15 +28,18 @@ use std::time::Duration;
 use clap::ArgMatches;
 use hurl::http;
 use hurl::http::RequestedHttpVersion;
+use hurl::runner::{Input, Output};
 use hurl::util::logger::{LoggerOptions, LoggerOptionsBuilder, Verbosity};
 use hurl::util::path::ContextDir;
 use hurl_core::ast::{Entry, Retry};
 
 use crate::cli;
 use crate::runner::{RunnerOptions, RunnerOptionsBuilder, Value};
+pub use error::CliOptionsError;
 
+/// Represents the list of all options that can be used in Hurl command line.
 #[derive(Clone, Debug, PartialEq, Eq)]
-pub struct Options {
+pub struct CliOptions {
     pub aws_sigv4: Option<String>,
     pub cacert_file: Option<String>,
     pub client_cert_file: Option<String>,
@@ -46,25 +50,32 @@ pub struct Options {
     pub connects_to: Vec<String>,
     pub continue_on_error: bool,
     pub cookie_input_file: Option<String>,
-    pub cookie_output_file: Option<String>,
+    pub cookie_output_file: Option<PathBuf>,
     pub delay: Duration,
     pub error_format: ErrorFormat,
     pub file_root: Option<String>,
     pub follow_location: bool,
     pub follow_location_trusted: bool,
+    pub from_entry: Option<usize>,
     pub html_dir: Option<PathBuf>,
     pub http_version: Option<HttpVersion>,
     pub ignore_asserts: bool,
     pub include: bool,
-    pub input_files: Vec<String>,
+    pub input_files: Vec<Input>,
     pub insecure: bool,
     pub interactive: bool,
     pub ip_resolve: Option<IpResolve>,
-    pub junit_file: Option<String>,
+    pub jobs: Option<usize>,
+    pub junit_file: Option<PathBuf>,
+    pub max_filesize: Option<u64>,
     pub max_redirect: Option<usize>,
+    pub netrc: bool,
+    pub netrc_file: Option<String>,
+    pub netrc_optional: bool,
     pub no_proxy: Option<String>,
-    pub output: Option<String>,
+    pub output: Option<Output>,
     pub output_type: OutputType,
+    pub parallel: bool,
     pub path_as_is: bool,
     pub progress_bar: bool,
     pub proxy: Option<String>,
@@ -72,7 +83,7 @@ pub struct Options {
     pub retry: Retry,
     pub retry_interval: Duration,
     pub ssl_no_revoke: bool,
-    pub tap_file: Option<String>,
+    pub tap_file: Option<PathBuf>,
     pub test: bool,
     pub timeout: Duration,
     pub to_entry: Option<usize>,
@@ -84,23 +95,6 @@ pub struct Options {
     pub very_verbose: bool,
 }
 
-#[derive(Clone, Debug, PartialEq, Eq)]
-pub enum OptionsError {
-    Info(String),
-    NoInput(String),
-    Error(String),
-}
-
-impl From<clap::Error> for OptionsError {
-    fn from(error: clap::Error) -> Self {
-        match error.kind() {
-            clap::error::ErrorKind::DisplayVersion => OptionsError::Info(error.to_string()),
-            clap::error::ErrorKind::DisplayHelp => OptionsError::Info(error.to_string()),
-            _ => OptionsError::Error(error.to_string()),
-        }
-    }
-}
-
 #[derive(Copy, Clone, Debug, PartialEq, Eq)]
 pub enum ErrorFormat {
     Short,
@@ -161,7 +155,7 @@ fn get_version() -> String {
     )
 }
 
-pub fn parse() -> Result<Options, OptionsError> {
+pub fn parse() -> Result<CliOptions, CliOptionsError> {
     let mut command = clap::Command::new("hurl")
         .version(get_version())
         .disable_colored_help(true)
@@ -183,6 +177,7 @@ pub fn parse() -> Result<Options, OptionsError> {
         .arg(commands::file_root())
         .arg(commands::follow_location())
         .arg(commands::follow_location_trusted())
+        .arg(commands::from_entry())
         .arg(commands::glob())
         .arg(commands::http10())
         .arg(commands::http11())
@@ -195,13 +190,19 @@ pub fn parse() -> Result<Options, OptionsError> {
         .arg(commands::interactive())
         .arg(commands::ipv4())
         .arg(commands::ipv6())
+        .arg(commands::jobs())
         .arg(commands::json())
+        .arg(commands::max_filesize())
         .arg(commands::max_redirects())
         .arg(commands::max_time())
+        .arg(commands::netrc())
+        .arg(commands::netrc_file())
+        .arg(commands::netrc_optional())
         .arg(commands::no_color())
         .arg(commands::no_output())
         .arg(commands::noproxy())
         .arg(commands::output())
+        .arg(commands::parallel())
         .arg(commands::path_as_is())
         .arg(commands::proxy())
         .arg(commands::report_html())
@@ -228,18 +229,18 @@ pub fn parse() -> Result<Options, OptionsError> {
     // we just print help and exit.
     if opts.input_files.is_empty() {
         let help = command.render_help().to_string();
-        return Err(OptionsError::NoInput(help));
+        return Err(CliOptionsError::NoInput(help));
     }
 
     if opts.cookie_output_file.is_some() && opts.input_files.len() > 1 {
-        return Err(OptionsError::Error(
+        return Err(CliOptionsError::Error(
             "Only save cookies for a unique session".to_string(),
         ));
     }
     Ok(opts)
 }
 
-fn parse_matches(arg_matches: &ArgMatches) -> Result<Options, OptionsError> {
+fn parse_matches(arg_matches: &ArgMatches) -> Result<CliOptions, CliOptionsError> {
     let aws_sigv4 = matches::aws_sigv4(arg_matches);
     let cacert_file = matches::cacert_file(arg_matches)?;
     let client_cert_file = matches::client_cert_file(arg_matches)?;
@@ -255,6 +256,7 @@ fn parse_matches(arg_matches: &ArgMatches) -> Result<Options, OptionsError> {
     let error_format = matches::error_format(arg_matches);
     let file_root = matches::file_root(arg_matches);
     let (follow_location, follow_location_trusted) = matches::follow_location(arg_matches);
+    let from_entry = matches::from_entry(arg_matches);
     let html_dir = matches::html_dir(arg_matches)?;
     let http_version = matches::http_version(arg_matches);
     let ignore_asserts = matches::ignore_asserts(arg_matches);
@@ -264,10 +266,15 @@ fn parse_matches(arg_matches: &ArgMatches) -> Result<Options, OptionsError> {
     let interactive = matches::interactive(arg_matches);
     let ip_resolve = matches::ip_resolve(arg_matches);
     let junit_file = matches::junit_file(arg_matches);
+    let max_filesize = matches::max_filesize(arg_matches);
     let max_redirect = matches::max_redirect(arg_matches);
+    let netrc = matches::netrc(arg_matches);
+    let netrc_file = matches::netrc_file(arg_matches)?;
+    let netrc_optional = matches::netrc_optional(arg_matches);
     let no_proxy = matches::no_proxy(arg_matches);
-    let progress_bar = matches::progress_bar(arg_matches);
+    let parallel = matches::parallel(arg_matches);
     let path_as_is = matches::path_as_is(arg_matches);
+    let progress_bar = matches::progress_bar(arg_matches);
     let proxy = matches::proxy(arg_matches);
     let output = matches::output(arg_matches);
     let output_type = matches::output_type(arg_matches);
@@ -285,7 +292,8 @@ fn parse_matches(arg_matches: &ArgMatches) -> Result<Options, OptionsError> {
     let variables = matches::variables(arg_matches)?;
     let verbose = matches::verbose(arg_matches);
     let very_verbose = matches::very_verbose(arg_matches);
-    Ok(Options {
+    let jobs = matches::jobs(arg_matches);
+    Ok(CliOptions {
         aws_sigv4,
         cacert_file,
         client_cert_file,
@@ -302,6 +310,7 @@ fn parse_matches(arg_matches: &ArgMatches) -> Result<Options, OptionsError> {
         file_root,
         follow_location,
         follow_location_trusted,
+        from_entry,
         html_dir,
         http_version,
         ignore_asserts,
@@ -311,9 +320,14 @@ fn parse_matches(arg_matches: &ArgMatches) -> Result<Options, OptionsError> {
         interactive,
         ip_resolve,
         junit_file,
+        max_filesize,
         max_redirect,
+        netrc,
+        netrc_file,
+        netrc_optional,
         no_proxy,
         path_as_is,
+        parallel,
         progress_bar,
         proxy,
         output,
@@ -332,18 +346,22 @@ fn parse_matches(arg_matches: &ArgMatches) -> Result<Options, OptionsError> {
         variables,
         verbose,
         very_verbose,
+        jobs,
     })
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum OutputType {
+    /// The last HTTP response body of a Hurl file is outputted on standard output.
     ResponseBody,
+    /// The whole Hurl file run is exported in a structured JSON export on standard output.
     Json,
+    /// Nothing is outputted on standard output when a Hurl file run is completed.
     NoOutput,
 }
 
-impl Options {
-    pub fn to_runner_options(&self, filename: &str, current_dir: &Path) -> RunnerOptions {
+impl CliOptions {
+    pub fn to_runner_options(&self, filename: &Input, current_dir: &Path) -> RunnerOptions {
         let aws_sigv4 = self.aws_sigv4.clone();
         let cacert_file = self.cacert_file.clone();
         let client_cert_file = self.client_cert_file.clone();
@@ -351,16 +369,12 @@ impl Options {
         let compressed = self.compressed;
         let connect_timeout = self.connect_timeout;
         let connects_to = self.connects_to.clone();
-        let file_root = match self.file_root {
-            Some(ref filename) => Path::new(filename),
-            None => {
-                if filename == "-" {
-                    current_dir
-                } else {
-                    let path = Path::new(filename);
-                    path.parent().unwrap()
-                }
-            }
+        let file_root = match &self.file_root {
+            Some(f) => Path::new(f),
+            None => match filename {
+                Input::File(path) => path.parent().unwrap(),
+                Input::Stdin => current_dir,
+            },
         };
         let context_dir = ContextDir::new(current_dir, file_root);
         let continue_on_error = self.continue_on_error;
@@ -368,6 +382,7 @@ impl Options {
         let delay = self.delay;
         let follow_location = self.follow_location;
         let follow_location_trusted = self.follow_location_trusted;
+        let from_entry = self.from_entry;
         let http_version = match self.http_version {
             Some(version) => version.into(),
             None => RequestedHttpVersion::default(),
@@ -378,39 +393,13 @@ impl Options {
             Some(ip) => ip.into(),
             None => http::IpResolve::default(),
         };
+        let max_filesize = self.max_filesize;
         let max_redirect = self.max_redirect;
+        let netrc = self.netrc;
+        let netrc_file = self.netrc_file.clone();
+        let netrc_optional = self.netrc_optional;
         let no_proxy = self.no_proxy.clone();
-        // FIXME:
-        // When used globally (on the command line), `--output` writes the last successful request
-        // to `output` file. We don't want to output every entry's response, so we initialise
-        // output to `None`.
-        // The straightforward code should have been `let output = self.output;` but if we do this
-        // every entry's response would have been dumped to stdout.
-        //
-        // If we compare with `--compressed`:
-        //
-        // ```
-        // cli.compressed = true =>
-        //   entry_1.compressed = true
-        //   entry_2.compressed = true
-        //     entry_2.overridden.compressed = false
-        //   entry_3.compressed = true
-        //   etc...
-        //   entry_last.compressed = true
-        // ```
-        //
-        // whereas
-        //
-        // ```
-        // cli.output = /tmp/out.bin =>
-        //   entry_1.output = None
-        //   entry_2.output = None
-        //     entry_2.overridden.output = /tmp/bar.bin
-        //   entry_3.output = None
-        //   etc...
-        //   entry_last.output = /tmp/out.bin
-        // ```
-        let output = None;
+        let output = self.output.clone();
         let path_as_is = self.path_as_is;
         let post_entry = if self.interactive {
             Some(cli::interactive::post_entry as fn() -> bool)
@@ -447,11 +436,16 @@ impl Options {
             .cookie_input_file(cookie_input_file)
             .follow_location(follow_location)
             .follow_location_trusted(follow_location_trusted)
+            .from_entry(from_entry)
             .http_version(http_version)
             .ignore_asserts(ignore_asserts)
             .insecure(insecure)
             .ip_resolve(ip_resolve)
+            .max_filesize(max_filesize)
             .max_redirect(max_redirect)
+            .netrc(netrc)
+            .netrc_file(netrc_file)
+            .netrc_optional(netrc_optional)
             .no_proxy(no_proxy)
             .output(output)
             .path_as_is(path_as_is)
@@ -470,15 +464,22 @@ impl Options {
             .build()
     }
 
-    pub fn to_logger_options(&self, filename: &str) -> LoggerOptions {
+    pub fn to_logger_options(
+        &self,
+        filename: &Input,
+        current_file: usize,
+        total_files: usize,
+    ) -> LoggerOptions {
         let verbosity = Verbosity::from(self.verbose, self.very_verbose);
         LoggerOptionsBuilder::new()
             .color(self.color)
             .error_format(self.error_format.into())
-            .filename(filename)
-            .progress_bar(self.progress_bar)
-            .test(self.test)
+            .filename(&filename.to_string())
             .verbosity(verbosity)
+            .test(self.test)
+            .progress_bar(self.progress_bar)
+            .current_file(current_file)
+            .total_files(total_files)
             .build()
     }
 }
