@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,11 +17,12 @@
  */
 use std::str;
 use std::str::FromStr;
+use std::time::Instant;
 
 use base64::engine::general_purpose;
 use base64::Engine;
 use chrono::Utc;
-use curl::easy::{List, SslOpt};
+use curl::easy::{List, NetRc, SslOpt};
 use curl::{easy, Version};
 use encoding::all::ISO_8859_1;
 use encoding::{DecoderTrap, Encoding};
@@ -29,12 +30,17 @@ use url::Url;
 
 use crate::http::certificate::Certificate;
 use crate::http::core::*;
+use crate::http::debug::log_body;
+use crate::http::header::{
+    HeaderVec, ACCEPT_ENCODING, AUTHORIZATION, CONTENT_TYPE, EXPECT, LOCATION, USER_AGENT,
+};
 use crate::http::options::ClientOptions;
 use crate::http::request::*;
 use crate::http::request_spec::*;
 use crate::http::response::*;
 use crate::http::timings::Timings;
 use crate::http::{easy_ext, Call, Header, HttpError, Verbosity};
+use crate::runner::Output;
 use crate::util::logger::Logger;
 use crate::util::path::ContextDir;
 
@@ -45,7 +51,7 @@ use crate::util::path::ContextDir;
 #[derive(Debug)]
 pub struct Client {
     /// The handle to libcurl binding
-    handle: Box<easy::Easy>,
+    handle: easy::Easy,
     /// Current State
     state: ClientState,
     /// HTTP version support
@@ -84,20 +90,19 @@ impl Client {
         let handle = easy::Easy::new();
         let version = Version::get();
         Client {
-            handle: Box::new(handle),
+            handle,
             state: ClientState::default(),
             http2: version.feature_http2(),
             http3: version.feature_http3(),
         }
     }
 
-    /// Executes an HTTP request `request_spec`, optionally follows redirection and returns a
-    /// list of pair of [`Request`], [`Response`].
+    /// Executes an HTTP request `request_spec`, optionally follows redirection and returns a list of [`Call`].
     pub fn execute_with_redirect(
         &mut self,
         request_spec: &RequestSpec,
         options: &ClientOptions,
-        logger: &Logger,
+        logger: &mut Logger,
     ) -> Result<Vec<Call>, HttpError> {
         let mut calls = vec![];
 
@@ -118,7 +123,7 @@ impl Client {
             }
             let redirect_url = redirect_url.unwrap();
             logger.debug("");
-            logger.debug(format!("=> Redirect to {redirect_url}").as_str());
+            logger.debug(&format!("=> Redirect to {redirect_url}"));
             logger.debug("");
             redirect_count += 1;
             if let Some(max_redirect) = options.max_redirect {
@@ -130,12 +135,8 @@ impl Client {
             let headers = if options.follow_location_trusted {
                 request_spec.headers
             } else {
-                request_spec
-                    .headers
-                    .iter()
-                    .filter(|header| header.name.to_lowercase() != "authorization")
-                    .cloned()
-                    .collect::<Vec<Header>>()
+                request_spec.headers.retain(|h| !h.name_eq(AUTHORIZATION));
+                request_spec.headers
             };
             request_spec = RequestSpec {
                 method: redirect_method,
@@ -148,12 +149,12 @@ impl Client {
     }
 
     /// Executes an HTTP request `request_spec`, without following redirection and returns a
-    /// pair of [`Request`], [`Response`].
+    /// pair of [`Call`].
     pub fn execute(
         &mut self,
         request_spec: &RequestSpec,
         options: &ClientOptions,
-        logger: &Logger,
+        logger: &mut Logger,
     ) -> Result<Call, HttpError> {
         // The handle can be mutated in this function: to start from a clean state, we reset it
         // prior to everything.
@@ -161,10 +162,11 @@ impl Client {
 
         let (url, method) = self.configure(request_spec, options, logger)?;
 
-        let start = Utc::now();
+        let start = Instant::now();
+        let start_dt = Utc::now();
         let verbose = options.verbosity.is_some();
         let very_verbose = options.verbosity == Some(Verbosity::VeryVerbose);
-        let mut request_headers: Vec<Header> = vec![];
+        let mut request_headers = HeaderVec::new();
         let mut status_lines = vec![];
         let mut response_headers = vec![];
         let has_body_data = !request_spec.body.bytes().is_empty()
@@ -184,63 +186,41 @@ impl Client {
             transfer.debug_function(|info_type, data| match info_type {
                 // Return all request headers (not one by one)
                 easy::InfoType::HeaderOut => {
-                    let mut lines = split_lines(data);
-                    logger.debug_method_version_out(&lines[0]);
-
+                    let lines = split_lines(data);
                     // Extracts request headers from libcurl debug info.
-                    lines.pop().unwrap(); // Remove last empty line.
-                    lines.remove(0); // Remove method/path/version line.
-                    for line in lines {
-                        if let Some(header) = Header::parse(&line) {
+                    // First line is method/path/version line, last line is empty
+                    for line in &lines[1..lines.len() - 1] {
+                        if let Some(header) = Header::parse(line) {
                             request_headers.push(header);
                         }
                     }
 
-                    // If we don't send any data, we log headers and empty body here
-                    // instead of relying on libcurl computing body in `easy::InfoType::DataOut`.
-                    // because libcurl dont call `easy::InfoType::DataOut` if there is no data
-                    // to send.
-                    if !has_body_data && verbose {
-                        let debug_request = Request {
-                            url: url.to_string(),
-                            method: method.to_string(),
-                            headers: request_headers.clone(),
-                            body: Vec::new(),
-                        };
-                        for header in &debug_request.headers {
-                            logger.debug_header_out(&header.name, &header.value);
-                        }
-                        logger.info(">");
+                    // Logs method, version and request headers now.
+                    if verbose {
+                        logger.debug_method_version_out(&lines[0]);
+                        let headers = request_headers
+                            .iter()
+                            .map(|h| (h.name.as_str(), h.value.as_str()))
+                            .collect::<Vec<_>>();
+                        logger.debug_headers_out(&headers);
+                    }
 
-                        if very_verbose {
-                            debug_request.log_body(true, logger);
-                        }
+                    // If we don't send any data, we log an empty body here instead of relying on
+                    // libcurl computing body in `easy::InfoType::DataOut` because libcurl doesn't
+                    // call `easy::InfoType::DataOut` if there is no data to send.
+                    if !has_body_data && very_verbose {
+                        logger.debug_important("Request body:");
+                        log_body(&[], &request_headers, true, logger);
                     }
                 }
-                // We use this callback to get the real body bytes sent by libcurl.
+                // We use this callback to get the real body bytes sent by libcurl and logs request
+                // body chunks.
                 easy::InfoType::DataOut => {
-                    // We log request headers with `easy::InfoType::DataOut` using libcurl
-                    // debug functions: there is no libcurl function to get the request headers.
-                    // As we can be called multiple times in this callback, we only log headers the
-                    // first time we send data (marked when the request body is empty).
-                    if verbose && request_body.is_empty() {
-                        let debug_request = Request {
-                            url: url.to_string(),
-                            method: method.to_string(),
-                            headers: request_headers.clone(),
-                            body: Vec::from(data),
-                        };
-                        for header in &debug_request.headers {
-                            logger.debug_header_out(&header.name, &header.value);
-                        }
-                        logger.info(">");
-
-                        if very_verbose {
-                            debug_request.log_body(true, logger);
-                        }
+                    if very_verbose {
+                        logger.debug_important("Request body:");
+                        log_body(data, &request_headers, true, logger);
                     }
-
-                    // Extracts request body from libcurl debug info.
+                    // Constructs request body from libcurl debug info.
                     request_body.extend(data);
                 }
                 // Curl debug logs
@@ -260,7 +240,7 @@ impl Client {
                     if s.starts_with("HTTP/") {
                         status_lines.push(s);
                     } else {
-                        response_headers.push(s)
+                        response_headers.push(s);
                     }
                 }
                 true
@@ -293,32 +273,27 @@ impl Client {
             match Certificate::try_from(cert_info) {
                 Ok(value) => Some(value),
                 Err(message) => {
-                    logger.error(format!("can not parse certificate - {message}").as_str());
+                    logger.error(&format!("can not parse certificate - {message}"));
                     None
                 }
             }
         } else {
             None
         };
-        let stop = Utc::now();
-        let duration = (stop - start).to_std().unwrap();
-        let timings = Timings::new(&mut self.handle, start, stop);
+        let duration = start.elapsed();
+        let stop_dt = start_dt + duration;
+        let timings = Timings::new(&mut self.handle, start_dt, stop_dt);
 
-        let request = Request {
-            url: url.clone(),
-            method: method.to_string(),
-            headers: request_headers,
-            body: request_body,
-        };
-        let response = Response {
+        let request = Request::new(&method.to_string(), &url, request_headers, request_body);
+        let response = Response::new(
             version,
             status,
             headers,
-            body: response_body,
+            response_body,
             duration,
-            url,
+            &url,
             certificate,
-        };
+        );
 
         if verbose {
             // FIXME: the cast to u64 seems not necessary.
@@ -326,9 +301,9 @@ impl Client {
             //  we have a segfault on Alpine Docker images and Rust 1.68.0, whereas it was
             //  ok with Rust >= 1.67.0.
             let duration = duration.as_millis() as u64;
-            logger.debug_important(
-                format!("Response: (received {length} bytes in {duration} ms)").as_str(),
-            );
+            logger.debug_important(&format!(
+                "Response: (received {length} bytes in {duration} ms)"
+            ));
             logger.debug("");
 
             // FIXME: Explain why there may be multiple status line
@@ -337,11 +312,15 @@ impl Client {
                 .filter(|s| s.starts_with("HTTP/"))
                 .for_each(|s| logger.debug_status_version_in(s.trim()));
 
-            for header in &response.headers {
-                logger.debug_header_in(&header.name, &header.value);
-            }
-            logger.info("<");
+            let headers = response
+                .headers
+                .iter()
+                .map(|h| (h.name.as_str(), h.value.as_str()))
+                .collect::<Vec<_>>();
+            logger.debug_headers_in(&headers);
+
             if very_verbose {
+                logger.debug_important("Response body:");
                 response.log_body(true, logger);
                 logger.debug("");
                 timings.log(logger);
@@ -361,7 +340,7 @@ impl Client {
         &mut self,
         request_spec: &RequestSpec,
         options: &ClientOptions,
-        logger: &Logger,
+        logger: &mut Logger,
     ) -> Result<(String, Method), HttpError> {
         // Activates cookie engine.
         // See <https://curl.se/libcurl/c/CURLOPT_COOKIEFILE.html>
@@ -418,7 +397,7 @@ impl Client {
         }
         self.handle.ssl_verify_host(!options.insecure)?;
         self.handle.ssl_verify_peer(!options.insecure)?;
-        if let Some(cacert_file) = options.cacert_file.clone() {
+        if let Some(cacert_file) = &options.cacert_file {
             self.handle.cainfo(cacert_file)?;
             self.handle.ssl_cert_type("PEM")?;
         }
@@ -434,22 +413,37 @@ impl Client {
             }
             self.handle.ssl_cert_type("PEM")?;
         }
-        if let Some(client_key_file) = options.client_key_file.clone() {
+        if let Some(client_key_file) = &options.client_key_file {
             self.handle.ssl_key(client_key_file)?;
             self.handle.ssl_cert_type("PEM")?;
         }
         self.handle.path_as_is(options.path_as_is)?;
-        if let Some(proxy) = options.proxy.clone() {
-            self.handle.proxy(proxy.as_str())?;
+        if let Some(proxy) = &options.proxy {
+            self.handle.proxy(proxy)?;
         }
-        if let Some(s) = options.no_proxy.clone() {
-            self.handle.noproxy(s.as_str())?;
+        if let Some(no_proxy) = &options.no_proxy {
+            self.handle.noproxy(no_proxy)?;
         }
         if let Some(unix_socket) = &options.unix_socket {
             self.handle.unix_socket(unix_socket)?;
         }
+        if let Some(filename) = &options.netrc_file {
+            easy_ext::netrc_file(&mut self.handle, filename)?;
+            self.handle.netrc(if options.netrc_optional {
+                NetRc::Optional
+            } else {
+                NetRc::Required
+            })?;
+        } else if options.netrc_optional {
+            self.handle.netrc(NetRc::Optional)?;
+        } else if options.netrc {
+            self.handle.netrc(NetRc::Required)?;
+        }
         self.handle.timeout(options.timeout)?;
         self.handle.connect_timeout(options.connect_timeout)?;
+        if let Some(max_filesize) = options.max_filesize {
+            self.handle.max_filesize(max_filesize)?;
+        }
 
         self.set_ssl_options(options.ssl_no_revoke)?;
 
@@ -506,46 +500,48 @@ impl Client {
     /// Sets HTTP headers.
     fn set_headers(
         &mut self,
-        request: &RequestSpec,
+        request_spec: &RequestSpec,
         options: &ClientOptions,
     ) -> Result<(), HttpError> {
         let mut list = List::new();
 
-        for header in &request.headers {
-            list.append(format!("{}: {}", header.name, header.value).as_str())?;
+        for header in &request_spec.headers {
+            list.append(&format!("{}: {}", header.name, header.value))?;
         }
 
-        if request.get_header_values("Content-Type").is_empty() {
-            if let Some(ref s) = request.content_type {
-                list.append(format!("Content-Type: {s}").as_str())?;
+        // If request has no Content-Type header, we set it if the content type has been set
+        // implicitly on this request.
+        if !request_spec.headers.contains_key(CONTENT_TYPE) {
+            if let Some(s) = &request_spec.implicit_content_type {
+                list.append(&format!("{}: {s}", CONTENT_TYPE))?;
             } else {
                 // We remove default Content-Type headers added by curl because we want
                 // to explicitly manage this header.
                 // For instance, with --data option, curl will send a 'Content-type: application/x-www-form-urlencoded'
                 // header.
-                list.append("Content-Type:")?;
+                list.append(&format!("{}:", CONTENT_TYPE))?;
             }
         }
 
-        // Workaround for libcurl issue #11664: When hurl explicitly sets `Expect:` to remove the header,
+        // Workaround for libcurl issue #11664: When Hurl explicitly sets `Expect:` to remove the header,
         // libcurl will generate `SignedHeaders` that include `expect` even though the header is not
         // present, causing some APIs to reject the request.
         // Therefore we only remove this header when not in aws_sigv4 mode.
-        if request.get_header_values("Expect").is_empty() && options.aws_sigv4.is_none() {
+        if !request_spec.headers.contains_key(EXPECT) && options.aws_sigv4.is_none() {
             // We remove default Expect headers added by curl because we want
             // to explicitly manage this header.
-            list.append("Expect:")?; // remove header Expect
+            list.append(&format!("{}:", EXPECT))?;
         }
 
-        if request.get_header_values("User-Agent").is_empty() {
+        if !request_spec.headers.contains_key(USER_AGENT) {
             let user_agent = match options.user_agent {
                 Some(ref u) => u.clone(),
                 None => format!("hurl/{}", clap::crate_version!()),
             };
-            list.append(format!("User-Agent: {user_agent}").as_str())?;
+            list.append(&format!("{}: {user_agent}", USER_AGENT))?;
         }
 
-        if let Some(ref user) = options.user {
+        if let Some(user) = &options.user {
             if options.aws_sigv4.is_some() {
                 // curl's aws_sigv4 support needs to know the username and password for the
                 // request, as it uses those values to calculate the Authorization header for the
@@ -557,13 +553,13 @@ impl Client {
             } else {
                 let user = user.as_bytes();
                 let authorization = general_purpose::STANDARD.encode(user);
-                if request.get_header_values("Authorization").is_empty() {
-                    list.append(format!("Authorization: Basic {authorization}").as_str())?;
+                if !request_spec.headers.contains_key(AUTHORIZATION) {
+                    list.append(&format!("{}: Basic {authorization}", AUTHORIZATION))?;
                 }
             }
         }
-        if options.compressed && request.get_header_values("Accept-Encoding").is_empty() {
-            list.append("Accept-Encoding: gzip, deflate, br")?;
+        if options.compressed && !request_spec.headers.contains_key(ACCEPT_ENCODING) {
+            list.append(&format!("{}: gzip, deflate, br", ACCEPT_ENCODING))?;
         }
 
         self.handle.http_headers(list)?;
@@ -601,7 +597,7 @@ impl Client {
                 // from libcurl::FormError to HttpError
                 match param {
                     MultipartParam::Param(Param { name, value }) => {
-                        form.part(name).contents(value.as_bytes()).add().unwrap()
+                        form.part(name).contents(value.as_bytes()).add().unwrap();
                     }
                     MultipartParam::FileParam(FileParam {
                         name,
@@ -666,8 +662,8 @@ impl Client {
     }
 
     /// Parse headers from libcurl responses.
-    fn parse_response_headers(&mut self, lines: &[String]) -> Vec<Header> {
-        let mut headers: Vec<Header> = vec![];
+    fn parse_response_headers(&mut self, lines: &[String]) -> HeaderVec {
+        let mut headers = HeaderVec::new();
         for line in lines {
             if let Some(header) = Header::parse(line) {
                 headers.push(header);
@@ -687,16 +683,10 @@ impl Client {
         if !(300..400).contains(&response_code) {
             return None;
         }
-        let location = match response.get_header_values("Location").first() {
-            None => return None,
-            Some(value) => get_redirect_url(value, base_url),
-        };
-
-        if location.is_empty() {
-            None
-        } else {
-            Some(location)
-        }
+        response
+            .headers
+            .get(LOCATION)
+            .map(|h| get_redirect_url(&h.value, base_url))
     }
 
     /// Returns cookie storage.
@@ -737,7 +727,7 @@ impl Client {
         &mut self,
         request_spec: &RequestSpec,
         context_dir: &ContextDir,
-        output: Option<&str>,
+        output: Option<&Output>,
         options: &ClientOptions,
     ) -> String {
         let mut arguments = vec!["curl".to_string()];
@@ -762,9 +752,17 @@ impl Client {
         arguments.append(&mut options.curl_args());
 
         // --output is not an option of the HTTP client, we deal with it here:
-        if let Some(output) = output {
-            arguments.push("--output".to_string());
-            arguments.push(output.to_string());
+        match output {
+            Some(Output::File(filename)) => {
+                let filename = context_dir.resolved_path(filename);
+                arguments.push("--output".to_string());
+                arguments.push(filename.to_string_lossy().to_string());
+            }
+            Some(Output::Stdout) => {
+                arguments.push("--output".to_string());
+                arguments.push("-".to_string());
+            }
+            None => {}
         }
 
         arguments.push(url);
@@ -954,6 +952,7 @@ impl From<IpResolve> for easy::IpResolve {
 mod tests {
     use super::*;
     use std::default::Default;
+    use std::path::PathBuf;
 
     #[test]
     fn test_parse_header() {
@@ -973,7 +972,7 @@ mod tests {
         let data = b"GET /hello HTTP/1.1\r\nHost: localhost:8000\r\n\r\n";
         let lines = split_lines(data);
         assert_eq!(lines.len(), 3);
-        assert_eq!(lines.get(0).unwrap().as_str(), "GET /hello HTTP/1.1");
+        assert_eq!(lines.first().unwrap().as_str(), "GET /hello HTTP/1.1");
         assert_eq!(lines.get(1).unwrap().as_str(), "Host: localhost:8000");
         assert_eq!(lines.get(2).unwrap().as_str(), "");
     }
@@ -1118,7 +1117,8 @@ mod tests {
             ..Default::default()
         };
         let context_dir = ContextDir::default();
-        let output = Some("/tmp/foo.bin");
+        let file = Output::File(PathBuf::from("/tmp/foo.bin"));
+        let output = Some(&file);
         let options = ClientOptions {
             aws_sigv4: Some("aws:amz:sts".to_string()),
             cacert_file: Some("/etc/cert.pem".to_string()),
