@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,13 +15,20 @@
  * limitations under the License.
  *
  */
+//! Various HTTP structures like requests, responses, cookies etc.
+//!
+//! The Hurl HTTP engine is not public. It's a wrapper around libcurl and only the models
+//! returned by an HTTP exchange are exposed.
 pub use self::call::Call;
 pub use self::certificate::Certificate;
 pub(crate) use self::client::Client;
 pub use self::cookie::{CookieAttribute, ResponseCookie};
-pub(crate) use self::core::{Cookie, Param, RequestCookie};
+pub use self::core::Cookie;
+pub(crate) use self::core::{Param, RequestCookie};
 pub(crate) use self::error::HttpError;
-pub use self::header::Header;
+pub use self::header::{
+    Header, HeaderVec, ACCEPT_ENCODING, AUTHORIZATION, CONTENT_TYPE, COOKIE, EXPECT, USER_AGENT,
+};
 pub(crate) use self::options::{ClientOptions, Verbosity};
 pub use self::request::{IpResolve, Request, RequestedHttpVersion};
 pub(crate) use self::request_spec::{Body, FileParam, Method, MultipartParam, RequestSpec};
@@ -40,11 +47,10 @@ mod debug;
 mod easy_ext;
 mod error;
 mod header;
+mod headers_helper;
 mod mimetype;
 mod options;
 mod request;
-mod request_debug;
-mod request_decoding;
 mod request_spec;
 mod request_spec_curl_args;
 mod response;
