@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,14 +15,15 @@
  * limitations under the License.
  *
  */
-use chrono::{DateTime, Utc};
+use chrono::{DateTime, SecondsFormat, Utc};
+use hurl_core::ast::SourceInfo;
 use serde_json::Number;
 
 use crate::http::{
     Call, Certificate, Cookie, Header, HttpVersion, Param, Request, RequestCookie, Response,
     ResponseCookie, Timings,
 };
-use crate::runner::{AssertResult, CaptureResult, EntryResult, HurlResult};
+use crate::runner::{AssertResult, CaptureResult, EntryResult, HurlResult, Input};
 use crate::util::logger;
 
 impl HurlResult {
@@ -31,7 +32,7 @@ impl HurlResult {
     /// Note: `content` is passed to this method to save asserts and
     /// errors messages (with lines and columns). This parameter will be removed
     /// soon and the original content will be accessible through the [`HurlResult`] instance.
-    pub fn to_json(&self, content: &str, filename: &str) -> serde_json::Value {
+    pub fn to_json(&self, content: &str, filename: &Input) -> serde_json::Value {
         let mut map = serde_json::Map::new();
         map.insert(
             "filename".to_string(),
@@ -55,7 +56,7 @@ impl HurlResult {
 }
 
 impl EntryResult {
-    fn to_json(&self, filename: &str, content: &str) -> serde_json::Value {
+    fn to_json(&self, filename: &Input, content: &str) -> serde_json::Value {
         let mut map = serde_json::Map::new();
 
         map.insert(
@@ -73,7 +74,7 @@ impl EntryResult {
         let asserts = self
             .asserts
             .iter()
-            .map(|a| a.to_json(filename, content))
+            .map(|a| a.to_json(filename, content, self.source_info))
             .collect();
         map.insert("asserts".to_string(), asserts);
         map.insert(
@@ -276,11 +277,11 @@ impl Timings {
         let mut map = serde_json::Map::new();
         map.insert(
             "begin_call".to_string(),
-            serde_json::Value::String(self.begin_call.to_string()),
+            serde_json::Value::String(self.begin_call.to_rfc3339_opts(SecondsFormat::Micros, true)),
         );
         map.insert(
             "end_call".to_string(),
-            serde_json::Value::String(self.end_call.to_string()),
+            serde_json::Value::String(self.end_call.to_rfc3339_opts(SecondsFormat::Micros, true)),
         );
         let value = self.name_lookup.as_micros() as u64;
         map.insert(
@@ -329,14 +330,25 @@ impl CaptureResult {
 }
 
 impl AssertResult {
-    fn to_json(&self, filename: &str, content: &str) -> serde_json::Value {
+    fn to_json(
+        &self,
+        filename: &Input,
+        content: &str,
+        entry_src_info: SourceInfo,
+    ) -> serde_json::Value {
         let mut map = serde_json::Map::new();
 
         let success = self.error().is_none();
         map.insert("success".to_string(), serde_json::Value::Bool(success));
 
         if let Some(err) = self.error() {
-            let message = logger::error_string(filename, content, &err, false);
+            let message = logger::error_string(
+                &filename.to_string(),
+                content,
+                &err,
+                Some(entry_src_info),
+                false,
+            );
             map.insert("message".to_string(), serde_json::Value::String(message));
         }
         map.insert(
