@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,19 +16,21 @@
  *
  */
 mod cli;
+mod run;
 
 use std::io::prelude::*;
 use std::path::Path;
 use std::time::Instant;
-use std::{env, process};
+use std::{env, process, thread};
 
+use crate::cli::CliError;
 use colored::control;
 use hurl::report::{html, junit, tap};
-use hurl::runner::HurlResult;
-use hurl::util::logger::{BaseLogger, Logger, LoggerOptionsBuilder, Verbosity};
-use hurl::{output, runner};
+use hurl::runner;
+use hurl::runner::{HurlResult, Input};
+use hurl::util::logger::BaseLogger;
 
-use crate::cli::options::OptionsError;
+use crate::cli::options::CliOptionsError;
 
 const EXIT_OK: i32 = 0;
 const EXIT_ERROR_COMMANDLINE: i32 = 1;
@@ -42,8 +44,8 @@ const EXIT_ERROR_UNDEFINED: i32 = 127;
 struct HurlRun {
     /// Source string for this [`HurlFile`]
     content: String,
-    /// Filename of the content
-    filename: String,
+    /// Content's source file
+    filename: Input,
     hurl_result: HurlResult,
 }
 
@@ -54,16 +56,12 @@ fn main() {
     let opts = match cli::options::parse() {
         Ok(v) => v,
         Err(e) => match e {
-            OptionsError::Info(message) => {
-                print!("{message}");
+            CliOptionsError::Info(_) => {
+                print!("{e}");
                 process::exit(EXIT_OK);
             }
-            OptionsError::NoInput(message) => {
-                eprintln!("{message}");
-                process::exit(EXIT_ERROR_COMMANDLINE);
-            }
-            OptionsError::Error(message) => {
-                eprintln!("error: {message}");
+            _ => {
+                eprintln!("{e}");
                 process::exit(EXIT_ERROR_COMMANDLINE);
             }
         },
@@ -77,90 +75,49 @@ fn main() {
     let current_dir = unwrap_or_exit(current_dir, EXIT_ERROR_UNDEFINED, &base_logger);
     let current_dir = current_dir.as_path();
     let start = Instant::now();
-    let mut runs = vec![];
 
-    for (current, filename) in opts.input_files.iter().enumerate() {
-        // We check the input file existence and check that we can read its contents.
-        // Once the preconditions succeed, we can parse the Hurl file, and run it.
-        if filename != "-" && !Path::new(filename).exists() {
-            let message = format!("hurl: cannot access '{filename}': No such file or directory");
-            exit_with_error(&message, EXIT_ERROR_PARSING, &base_logger);
-        }
-        let content = cli::read_to_string(filename.as_str());
-        let content = unwrap_or_exit(content, EXIT_ERROR_PARSING, &base_logger);
+    let runs = if opts.parallel {
+        let available = unwrap_or_exit(
+            thread::available_parallelism(),
+            EXIT_ERROR_UNDEFINED,
+            &base_logger,
+        );
+        let workers_count = opts.jobs.unwrap_or(available.get());
+        base_logger.debug(&format!("Parallel run using {workers_count} workers"));
 
-        let verbosity = Verbosity::from(opts.verbose, opts.very_verbose);
-        let logger_options = LoggerOptionsBuilder::new()
-            .color(opts.color)
-            .error_format(opts.error_format.into())
-            .filename(filename)
-            .progress_bar(opts.progress_bar)
-            .test(opts.test)
-            .verbosity(verbosity)
-            .build();
-        let logger = Logger::from(&logger_options);
-        let total = opts.input_files.len();
-        logger.test_running(current + 1, total);
-
-        // Run our Hurl file now
-        let hurl_result = execute(&content, filename, current_dir, &opts);
-        let hurl_result = match hurl_result {
-            Ok(h) => h,
-            Err(_) => process::exit(EXIT_ERROR_PARSING),
-        };
-
-        logger.test_completed(&hurl_result);
-        let success = hurl_result.success;
-
-        // We can output the result, either the raw body or a structured JSON representation.
-        let output_body = success
-            && !opts.interactive
-            && matches!(opts.output_type, cli::OutputType::ResponseBody);
-        if output_body {
-            let include_headers = opts.include;
-            let result = output::write_body(
-                &hurl_result,
-                filename,
-                include_headers,
-                opts.color,
-                &opts.output,
-                &logger,
-            );
-            unwrap_or_exit(result, EXIT_ERROR_RUNTIME, &base_logger);
-        }
-        if matches!(opts.output_type, cli::OutputType::Json) {
-            let result = output::write_json(&hurl_result, &content, filename, &opts.output);
-            unwrap_or_exit(result, EXIT_ERROR_RUNTIME, &base_logger);
-        }
-
-        let run = HurlRun {
-            content,
-            filename: filename.to_string(),
-            hurl_result,
-        };
-        runs.push(run);
-    }
+        run::run_par(&opts.input_files, current_dir, &opts, workers_count)
+    } else {
+        run::run_seq(&opts.input_files, current_dir, &opts)
+    };
+    let runs = match runs {
+        Ok(r) => r,
+        Err(CliError::IO(msg)) => exit_with_error(&msg, EXIT_ERROR_PARSING, &base_logger),
+        // In case of parsing error, there is no error because the display of parsing error has been
+        // done in the execution of the Hurl files, inside the crates (and not in the main).
+        Err(CliError::Parsing) => exit_with_error("", EXIT_ERROR_PARSING, &base_logger),
+        Err(CliError::Runtime(msg)) => exit_with_error(&msg, EXIT_ERROR_RUNTIME, &base_logger),
+    };
 
     if let Some(filename) = opts.junit_file {
-        base_logger.debug(format!("Writing JUnit report to {filename}").as_str());
+        base_logger.debug(&format!("Writing JUnit report to {}", filename.display()));
         let result = create_junit_report(&runs, &filename);
         unwrap_or_exit(result, EXIT_ERROR_UNDEFINED, &base_logger);
     }
 
     if let Some(filename) = opts.tap_file {
-        base_logger.debug(format!("Writing TAP report to {filename}").as_str());
+        base_logger.debug(&format!("Writing TAP report to {}", filename.display()));
         let result = create_tap_report(&runs, &filename);
         unwrap_or_exit(result, EXIT_ERROR_UNDEFINED, &base_logger);
     }
 
     if let Some(dir) = opts.html_dir {
-        base_logger.debug(format!("Writing HTML report to {}", dir.display()).as_str());
+        base_logger.debug(&format!("Writing HTML report to {}", dir.display()));
         let result = create_html_report(&runs, &dir);
         unwrap_or_exit(result, EXIT_ERROR_UNDEFINED, &base_logger);
     }
 
     if let Some(filename) = opts.cookie_output_file {
-        base_logger.debug(format!("Writing cookies to {filename}").as_str());
+        base_logger.debug(&format!("Writing cookies to {}", filename.display()));
         let result = create_cookies_file(&runs, &filename);
         unwrap_or_exit(result, EXIT_ERROR_UNDEFINED, &base_logger);
     }
@@ -174,19 +131,6 @@ fn main() {
     process::exit(exit_code(&runs));
 }
 
-/// Runs a Hurl `content` and returns a result.
-fn execute(
-    content: &str,
-    filename: &str,
-    current_dir: &Path,
-    cli_options: &cli::options::Options,
-) -> Result<HurlResult, String> {
-    let variables = &cli_options.variables;
-    let runner_options = cli_options.to_runner_options(filename, current_dir);
-    let logger_options = cli_options.to_logger_options(filename);
-    runner::run(content, &runner_options, variables, &logger_options)
-}
-
 #[cfg(target_family = "unix")]
 fn init_colored() {
     control::set_override(true);
@@ -218,27 +162,27 @@ fn exit_with_error(message: &str, code: i32, logger: &BaseLogger) -> ! {
 }
 
 /// Create a JUnit report for this run.
-fn create_junit_report(runs: &[HurlRun], filename: &str) -> Result<(), cli::CliError> {
-    let testcases: Vec<junit::Testcase> = runs
+fn create_junit_report(runs: &[HurlRun], filename: &Path) -> Result<(), CliError> {
+    let testcases = runs
         .iter()
         .map(|r| junit::Testcase::from(&r.hurl_result, &r.content, &r.filename))
-        .collect();
+        .collect::<Vec<_>>();
     junit::write_report(filename, &testcases)?;
     Ok(())
 }
 
 /// Create a TAP report for this run.
-fn create_tap_report(runs: &[HurlRun], filename: &str) -> Result<(), cli::CliError> {
-    let testcases: Vec<tap::Testcase> = runs
+fn create_tap_report(runs: &[HurlRun], filename: &Path) -> Result<(), CliError> {
+    let testcases = runs
         .iter()
         .map(|r| tap::Testcase::from(&r.hurl_result, &r.filename))
-        .collect();
+        .collect::<Vec<_>>();
     tap::write_report(filename, &testcases)?;
     Ok(())
 }
 
 /// Create an HTML report for this run.
-fn create_html_report(runs: &[HurlRun], dir_path: &Path) -> Result<(), cli::CliError> {
+fn create_html_report(runs: &[HurlRun], dir_path: &Path) -> Result<(), CliError> {
     // We ensure that the containing folder exists.
     std::fs::create_dir_all(dir_path.join("store")).unwrap();
 
@@ -259,7 +203,7 @@ fn exit_code(runs: &[HurlRun]) -> i32 {
     for run in runs.iter() {
         let errors = run.hurl_result.errors();
         if errors.is_empty() {
-        } else if errors.iter().filter(|e| !e.assert).count() == 0 {
+        } else if errors.iter().filter(|(error, _)| !error.assert).count() == 0 {
             count_errors_assert += 1;
         } else {
             count_errors_runner += 1;
@@ -274,12 +218,13 @@ fn exit_code(runs: &[HurlRun]) -> i32 {
     }
 }
 
-fn create_cookies_file(runs: &[HurlRun], filename: &str) -> Result<(), cli::CliError> {
+fn create_cookies_file(runs: &[HurlRun], filename: &Path) -> Result<(), CliError> {
     let mut file = match std::fs::File::create(filename) {
         Err(why) => {
-            return Err(cli::CliError {
-                message: format!("Issue writing to {filename}: {why:?}"),
-            });
+            return Err(CliError::IO(format!(
+                "Issue writing to {}: {why:?}",
+                filename.display()
+            )));
         }
         Ok(file) => file,
     };
@@ -290,9 +235,7 @@ fn create_cookies_file(runs: &[HurlRun], filename: &str) -> Result<(), cli::CliE
     .to_string();
     match runs.first() {
         None => {
-            return Err(cli::CliError {
-                message: "Issue fetching results".to_string(),
-            });
+            return Err(CliError::IO("Issue fetching results".to_string()));
         }
         Some(run) => {
             for cookie in run.hurl_result.cookies.iter() {
@@ -303,9 +246,10 @@ fn create_cookies_file(runs: &[HurlRun], filename: &str) -> Result<(), cli::CliE
     }
 
     if let Err(why) = file.write_all(s.as_bytes()) {
-        return Err(cli::CliError {
-            message: format!("Issue writing to {filename}: {why:?}"),
-        });
+        return Err(CliError::IO(format!(
+            "Issue writing to {}: {why:?}",
+            filename.display()
+        )));
     }
     Ok(())
 }
@@ -348,7 +292,7 @@ pub mod tests {
             };
             HurlRun {
                 content: String::new(),
-                filename: String::new(),
+                filename: Input::new(""),
                 hurl_result: HurlResult {
                     entries: vec![dummy_entry; entries_count],
                     time_in_ms: 0,
