@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,14 +17,16 @@
  */
 //! Serialize a Hurl run result to a file.
 //!
-//! Therea are two supported serialisation:
+//! There are two supported serialisation:
+//!
 //! - JSON: the whole run is serialized to JSON (like the [HAR](https://en.wikipedia.org/wiki/HAR_(file_format)) format)
+//! [`self::json::write_json`]
 //! - raw: the last response of a run is serialized to a file. The body can be automatically uncompress
-//! or written as it.
+//! or written as it [`self::raw::write_last_body`]
 mod error;
 mod json;
 mod raw;
 
 pub use self::error::Error;
 pub use self::json::write_json;
-pub use self::raw::write_body;
+pub use self::raw::write_last_body;
