@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ use std::path::Path;
 use hurl_core::parser;
 use uuid::Uuid;
 
-use crate::runner::{EntryResult, Error, HurlResult};
+use crate::runner::{EntryResult, Error, HurlResult, Input};
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct Testcase {
@@ -36,9 +36,13 @@ pub struct Testcase {
 
 impl Testcase {
     /// Creates an HTML testcase.
-    pub fn from(hurl_result: &HurlResult, filename: &str) -> Testcase {
+    pub fn from(hurl_result: &HurlResult, filename: &Input) -> Testcase {
         let id = Uuid::new_v4();
-        let errors = hurl_result.errors().into_iter().cloned().collect();
+        let errors = hurl_result
+            .errors()
+            .into_iter()
+            .map(|(e, _)| e.clone())
+            .collect();
         Testcase {
             id: id.to_string(),
             filename: filename.to_string(),
