@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -57,6 +57,7 @@
 mod testcase;
 mod xml;
 use std::fs::File;
+use std::path::Path;
 
 pub use testcase::Testcase;
 
@@ -64,15 +65,18 @@ use crate::report::junit::xml::{Element, XmlDocument};
 use crate::report::Error;
 
 /// Creates a JUnit from a list of `testcases`.
-pub fn write_report(filename: &str, testcases: &[Testcase]) -> Result<(), Error> {
+pub fn write_report(filename: &Path, testcases: &[Testcase]) -> Result<(), Error> {
     // If there is an existing JUnit report, we parses it to insert a new testsuite.
-    let path = std::path::Path::new(&filename);
-    let mut root = if path.exists() {
-        let file = match File::open(path) {
+    let mut root = if filename.exists() {
+        let file = match File::open(filename) {
             Ok(s) => s,
             Err(why) => {
                 return Err(Error {
-                    message: format!("Issue reading {} to string to {:?}", path.display(), why),
+                    message: format!(
+                        "Issue reading {} to string to {:?}",
+                        filename.display(),
+                        why
+                    ),
                 });
             }
         };
@@ -132,13 +136,13 @@ mod tests {
 
     use crate::report::junit::xml::XmlDocument;
     use crate::report::junit::{create_testsuite, Testcase};
-    use crate::runner::{EntryResult, Error, HurlResult, RunnerError};
+    use crate::runner::{EntryResult, Error, HurlResult, Input, RunnerError};
 
     #[test]
     fn create_junit_report() {
         let content = "GET http://localhost:8000/not_found\n\
                        HTTP/1.0 200";
-        let filename = "-";
+        let filename = Input::Stdin;
         let mut testcases = vec![];
         let res = HurlResult {
             entries: vec![],
@@ -147,7 +151,7 @@ mod tests {
             cookies: vec![],
             timestamp: 1,
         };
-        let tc = Testcase::from(&res, content, filename);
+        let tc = Testcase::from(&res, content, &filename);
         testcases.push(tc);
 
         let res = HurlResult {
@@ -172,7 +176,7 @@ mod tests {
             cookies: vec![],
             timestamp: 1,
         };
-        let tc = Testcase::from(&res, content, filename);
+        let tc = Testcase::from(&res, content, &filename);
         testcases.push(tc);
 
         let res = HurlResult {
@@ -195,7 +199,7 @@ mod tests {
             cookies: vec![],
             timestamp: 1,
         };
-        let tc = Testcase::from(&res, content, filename);
+        let tc = Testcase::from(&res, content, &filename);
         testcases.push(tc);
 
         let suite = create_testsuite(&testcases);
@@ -207,15 +211,16 @@ mod tests {
                 <testcase id=\"-\" name=\"-\" time=\"0.230\" />\
                 <testcase id=\"-\" name=\"-\" time=\"0.230\">\
                     <failure>Assert status code\n  \
-                    --> -:2:10\n   \
-                      |\n \
+                    --&gt; -:2:10\n   \
+                      |\n   \
+                      | GET http://localhost:8000/not_found\n \
                     2 | HTTP/1.0 200\n   \
-                      |          ^^^ actual value is &lt;404>\n   \
+                      |          ^^^ actual value is &lt;404&gt;\n   \
                       |\
                     </failure>\
                 </testcase>\
                 <testcase id=\"-\" name=\"-\" time=\"0.230\">\
-                    <error>HTTP connection\n  --> -:1:5\n   |\n 1 | GET http://localhost:8000/not_found\n   |     ^^^^^^^^^^^^^^ (6) Could not resolve host: unknown\n   |\
+                    <error>HTTP connection\n  --&gt; -:1:5\n   |\n 1 | GET http://localhost:8000/not_found\n   |     ^^^^^^^^^^^^^^ (6) Could not resolve host: unknown\n   |\
                     </error>\
                 </testcase>\
             </testsuite>"
