@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -73,17 +73,18 @@ pub fn eval_file(
     let file = eval_template(filename, variables)?;
     // In order not to leak any private date, we check that the user provided file
     // is a child of the context directory.
-    if !context_dir.is_access_allowed(&file) {
-        let inner = RunnerError::UnauthorizedFileAccess {
-            path: PathBuf::from(file),
-        };
+    let path = PathBuf::from(file);
+    if !context_dir.is_access_allowed(&path) {
+        let inner = RunnerError::UnauthorizedFileAccess { path };
         return Err(Error::new(filename.source_info, inner, false));
     }
-    let resolved_file = context_dir.get_path(&file);
-    let inner = RunnerError::FileReadAccess { file };
+    let resolved_file = context_dir.resolved_path(&path);
     match std::fs::read(resolved_file) {
         Ok(value) => Ok(value),
-        Err(_) => Err(Error::new(filename.source_info, inner, false)),
+        Err(_) => {
+            let inner = RunnerError::FileReadAccess { path };
+            Err(Error::new(filename.source_info, inner, false))
+        }
     }
 }
 
@@ -156,7 +157,7 @@ mod tests {
         assert_eq!(
             error.inner,
             RunnerError::FileReadAccess {
-                file: "data.bin".to_string()
+                path: PathBuf::from("data.bin")
             }
         );
         assert_eq!(
