@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -169,7 +169,7 @@ pub mod tests {
             .err()
             .unwrap();
         assert_eq!(error.source_info.start, Pos { line: 1, column: 7 });
-        assert_eq!(error.inner, RunnerError::QueryInvalidXpathEval)
+        assert_eq!(error.inner, RunnerError::QueryInvalidXpathEval);
     }
 
     #[test]
