@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,11 +23,10 @@ use hurl_core::ast::*;
 use crate::http;
 use crate::http::ClientOptions;
 use crate::runner::error::Error;
-use crate::runner::request::{cookie_storage_clear, cookie_storage_set, eval_request};
-use crate::runner::response::{eval_asserts, eval_captures, eval_version_status_asserts};
 use crate::runner::result::{AssertResult, EntryResult};
 use crate::runner::runner_options::RunnerOptions;
 use crate::runner::value::Value;
+use crate::runner::{request, response, CaptureResult};
 use crate::util::logger::{Logger, Verbosity};
 
 /// Runs an `entry` with `http_client` and returns one [`EntryResult`].
@@ -42,21 +41,20 @@ pub fn run(
     http_client: &mut http::Client,
     variables: &mut HashMap<String, Value>,
     runner_options: &RunnerOptions,
-    logger: &Logger,
+    logger: &mut Logger,
 ) -> EntryResult {
+    let compressed = runner_options.compressed;
+    let source_info = entry.source_info();
     let context_dir = &runner_options.context_dir;
-    let http_request = match eval_request(&entry.request, variables, context_dir) {
+    let http_request = match request::eval_request(&entry.request, variables, context_dir) {
         Ok(r) => r,
         Err(error) => {
             return EntryResult {
                 entry_index,
-                source_info: entry.source_info(),
-                calls: vec![],
-                captures: vec![],
-                asserts: vec![],
+                source_info,
                 errors: vec![error],
-                time_in_ms: 0,
-                compressed: runner_options.compressed,
+                compressed,
+                ..Default::default()
             };
         }
     };
@@ -64,35 +62,24 @@ pub fn run(
 
     // Experimental features with cookie storage
     use std::str::FromStr;
-    if let Some(s) = cookie_storage_set(&entry.request) {
+    if let Some(s) = request::cookie_storage_set(&entry.request) {
         if let Ok(cookie) = http::Cookie::from_str(s.as_str()) {
             http_client.add_cookie(&cookie, &client_options);
         } else {
-            logger.warning(format!("Cookie string can not be parsed: '{s}'").as_str());
+            logger.warning(&format!("Cookie string can not be parsed: '{s}'"));
         }
     }
-    if cookie_storage_clear(&entry.request) {
+    if request::cookie_storage_clear(&entry.request) {
         http_client.clear_cookie_storage(&client_options);
     }
 
-    logger.debug("");
-    logger.debug_important("Cookie store:");
-    for cookie in http_client.get_cookie_storage() {
-        logger.debug(cookie.to_string().as_str());
-    }
-    logger.debug("");
-    log_request_spec(&http_request, logger);
-
-    logger.debug("Request can be run with the following curl command:");
-    let output = &runner_options.output;
-    let curl_command = http_client.curl_command_line(
+    log_request(
+        http_client,
         &http_request,
-        context_dir,
-        output.as_deref(),
+        runner_options,
         &client_options,
+        logger,
     );
-    logger.debug(curl_command.as_str());
-    logger.debug("");
 
     // Run the HTTP requests (optionally follow redirection)
     let calls = match http_client.execute_with_redirect(&http_request, &client_options, logger) {
@@ -104,13 +91,10 @@ pub fn run(
             let error = Error::new(error_source_info, http_error.into(), false);
             return EntryResult {
                 entry_index,
-                source_info: entry.source_info(),
-                calls: vec![],
-                captures: vec![],
-                asserts: vec![],
+                source_info,
                 errors: vec![error],
-                time_in_ms: 0,
-                compressed: client_options.compressed,
+                compressed,
+                ..Default::default()
             };
         }
     };
@@ -129,75 +113,73 @@ pub fn run(
     // 1. first, check implicit assert on status and version. If KO, test is failed
     // 2. then, we compute captures, we might need them in asserts
     // 3. finally, run the remaining asserts
-    let mut all_asserts = vec![];
+    let mut asserts = vec![];
 
     if !runner_options.ignore_asserts {
         if let Some(response_spec) = &entry.response {
-            let mut asserts = eval_version_status_asserts(response_spec, http_response);
-            let errors = asserts_to_errors(&asserts);
+            let mut status_asserts =
+                response::eval_version_status_asserts(response_spec, http_response);
+            let errors = asserts_to_errors(&status_asserts);
+            asserts.append(&mut status_asserts);
             if !errors.is_empty() {
                 logger.debug("");
                 return EntryResult {
                     entry_index,
-                    source_info: entry.source_info(),
+                    source_info,
                     calls,
                     captures: vec![],
                     asserts,
                     errors,
                     time_in_ms,
-                    compressed: client_options.compressed,
+                    compressed,
                 };
             }
-            all_asserts.append(&mut asserts);
         }
     };
 
     let captures = match &entry.response {
         None => vec![],
-        Some(response_spec) => match eval_captures(response_spec, http_response, variables) {
-            Ok(captures) => captures,
-            Err(e) => {
-                return EntryResult {
-                    entry_index,
-                    source_info: entry.source_info(),
-                    calls,
-                    captures: vec![],
-                    asserts: all_asserts,
-                    errors: vec![e],
-                    time_in_ms,
-                    compressed: client_options.compressed,
-                };
+        Some(response_spec) => {
+            match response::eval_captures(response_spec, http_response, variables) {
+                Ok(captures) => captures,
+                Err(e) => {
+                    return EntryResult {
+                        entry_index,
+                        source_info,
+                        calls,
+                        captures: vec![],
+                        asserts,
+                        errors: vec![e],
+                        time_in_ms,
+                        compressed,
+                    };
+                }
             }
-        },
-    };
-
-    if !captures.is_empty() {
-        logger.debug_important("Captures:");
-        for c in captures.iter() {
-            logger.capture(&c.name, &c.value);
         }
-    }
+    };
+    log_captures(&captures, logger);
     logger.debug("");
 
     // Compute asserts
     if !runner_options.ignore_asserts {
         if let Some(response_spec) = &entry.response {
-            let mut asserts = eval_asserts(response_spec, variables, http_response, context_dir);
-            all_asserts.append(&mut asserts);
+            let mut other_asserts =
+                response::eval_asserts(response_spec, variables, http_response, context_dir);
+            asserts.append(&mut other_asserts);
         }
     };
 
-    let errors = asserts_to_errors(&all_asserts);
+    let errors = asserts_to_errors(&asserts);
 
     EntryResult {
         entry_index,
-        source_info: entry.source_info(),
+        source_info,
         calls,
         captures,
-        asserts: all_asserts,
+        asserts,
         errors,
         time_in_ms,
-        compressed: client_options.compressed,
+        compressed,
     }
 }
 
@@ -229,7 +211,11 @@ impl ClientOptions {
             follow_location_trusted: runner_options.follow_location_trusted,
             http_version: runner_options.http_version,
             ip_resolve: runner_options.ip_resolve,
+            max_filesize: runner_options.max_filesize,
             max_redirect: runner_options.max_redirect,
+            netrc: runner_options.netrc,
+            netrc_file: runner_options.netrc_file.clone(),
+            netrc_optional: runner_options.netrc_optional,
             path_as_is: runner_options.path_as_is,
             proxy: runner_options.proxy.clone(),
             no_proxy: runner_options.no_proxy.clone(),
@@ -250,40 +236,67 @@ impl ClientOptions {
     }
 }
 
-/// Logs this HTTP `request` spec.
-fn log_request_spec(request: &http::RequestSpec, logger: &Logger) {
+/// Logs this HTTP `request`.
+fn log_request(
+    http_client: &mut http::Client,
+    request: &http::RequestSpec,
+    runner_options: &RunnerOptions,
+    client_options: &ClientOptions,
+    logger: &mut Logger,
+) {
+    logger.debug("");
+    logger.debug_important("Cookie store:");
+    for cookie in &http_client.get_cookie_storage() {
+        logger.debug(&cookie.to_string());
+    }
+
+    logger.debug("");
     logger.debug_important("Request:");
-    logger.debug(format!("{} {}", request.method, request.url).as_str());
+    logger.debug(&format!("{} {}", request.method, request.url));
     for header in &request.headers {
-        logger.debug(header.to_string().as_str());
+        logger.debug(&header.to_string());
     }
     if !request.querystring.is_empty() {
         logger.debug("[QueryStringParams]");
         for param in &request.querystring {
-            logger.debug(param.to_string().as_str());
+            logger.debug(&param.to_string());
         }
     }
     if !request.form.is_empty() {
         logger.debug("[FormParams]");
         for param in &request.form {
-            logger.debug(param.to_string().as_str());
+            logger.debug(&param.to_string());
         }
     }
     if !request.multipart.is_empty() {
         logger.debug("[MultipartFormData]");
         for param in &request.multipart {
-            logger.debug(param.to_string().as_str());
+            logger.debug(&param.to_string());
         }
     }
     if !request.cookies.is_empty() {
         logger.debug("[Cookies]");
         for cookie in &request.cookies {
-            logger.debug(cookie.to_string().as_str());
+            logger.debug(&cookie.to_string());
         }
     }
-    if let Some(s) = &request.content_type {
-        logger.debug("");
-        logger.debug(format!("Implicit content-type={s}").as_str());
-    }
+    logger.debug("");
+    logger.debug("Request can be run with the following curl command:");
+    let context_dir = &runner_options.context_dir;
+    let output = &runner_options.output;
+    let curl_command =
+        http_client.curl_command_line(request, context_dir, output.as_ref(), client_options);
+    logger.debug(&curl_command);
     logger.debug("");
 }
+
+/// Logs the `captures` from the entry HTTP response.
+fn log_captures(captures: &[CaptureResult], logger: &mut Logger) {
+    if captures.is_empty() {
+        return;
+    }
+    logger.debug_important("Captures:");
+    for c in captures.iter() {
+        logger.capture(&c.name, &c.value);
+    }
+}
