@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -62,14 +62,14 @@ pub enum RunnerError {
     AssertVersion {
         actual: String,
     },
-    CouldNotParseResponse,
     CouldNotUncompressResponse(String),
+    /// I/O read error on `path`.
     FileReadAccess {
-        file: String,
+        path: PathBuf,
     },
-    // I/O write error on a path
+    /// I/O write error on `path`.
     FileWriteAccess {
-        file: String,
+        path: PathBuf,
         error: String,
     },
     FilterDecode(String),
@@ -87,8 +87,7 @@ pub enum RunnerError {
         charset: String,
     },
     InvalidRegex,
-    InvalidUrl(String),
-    InvalidUrlPrefix(String),
+    InvalidUrl(String, String),
     NoQueryResult,
     QueryHeaderNotFound,
     QueryInvalidJsonpathExpression {
@@ -112,6 +111,7 @@ pub enum RunnerError {
         name: String,
         value: String,
     },
+    /// Unauthorized file access, check `--file-root` option.
     UnauthorizedFileAccess {
         path: PathBuf,
     },
@@ -130,21 +130,19 @@ impl hurl_core::error::Error for Error {
             RunnerError::AssertHeaderValueError { .. } => "Assert header value".to_string(),
             RunnerError::AssertStatus { .. } => "Assert status code".to_string(),
             RunnerError::AssertVersion { .. } => "Assert HTTP version".to_string(),
-            RunnerError::CouldNotParseResponse => "HTTP connection".to_string(),
             RunnerError::CouldNotUncompressResponse(..) => "Decompression error".to_string(),
             RunnerError::FileReadAccess { .. } => "File read access".to_string(),
             RunnerError::FileWriteAccess { .. } => "File write access".to_string(),
-            RunnerError::FilterDecode { .. } => "Filter Error".to_string(),
-            RunnerError::FilterInvalidEncoding { .. } => "Filter Error".to_string(),
-            RunnerError::FilterInvalidInput { .. } => "Filter Error".to_string(),
-            RunnerError::FilterMissingInput => "Filter Error".to_string(),
+            RunnerError::FilterDecode { .. } => "Filter error".to_string(),
+            RunnerError::FilterInvalidEncoding { .. } => "Filter error".to_string(),
+            RunnerError::FilterInvalidInput { .. } => "Filter error".to_string(),
+            RunnerError::FilterMissingInput => "Filter error".to_string(),
             RunnerError::HttpConnection { .. } => "HTTP connection".to_string(),
             RunnerError::InvalidCharset { .. } => "Invalid charset".to_string(),
             RunnerError::InvalidDecoding { .. } => "Invalid decoding".to_string(),
             RunnerError::InvalidJson { .. } => "Invalid JSON".to_string(),
             RunnerError::InvalidRegex => "Invalid regex".to_string(),
             RunnerError::InvalidUrl(..) => "Invalid URL".to_string(),
-            RunnerError::InvalidUrlPrefix(..) => "Invalid URL".to_string(),
             RunnerError::NoQueryResult => "No query result".to_string(),
             RunnerError::QueryHeaderNotFound => "Header not found".to_string(),
             RunnerError::QueryInvalidJson => "Invalid JSON".to_string(),
@@ -173,24 +171,25 @@ impl hurl_core::error::Error for Error {
                 ..
             } => {
                 let additional = if *type_mismatch {
-                    "\n>>> types between actual and expected are not consistent"
+                    "\n   >>> types between actual and expected are not consistent"
                 } else {
                     ""
                 };
-                format!("actual:   {actual}\nexpected: {expected}{additional}")
+                format!("   actual:   {actual}\n   expected: {expected}{additional}")
             }
             RunnerError::AssertHeaderValueError { actual } => {
                 format!("actual value is <{actual}>")
             }
             RunnerError::AssertStatus { actual, .. } => format!("actual value is <{actual}>"),
             RunnerError::AssertVersion { actual, .. } => format!("actual value is <{actual}>"),
-            RunnerError::CouldNotParseResponse => "could not parse response".to_string(),
             RunnerError::CouldNotUncompressResponse(algorithm) => {
                 format!("could not uncompress response with {algorithm}")
             }
-            RunnerError::FileReadAccess { file } => format!("file {file} can not be read"),
-            RunnerError::FileWriteAccess { file, error } => {
-                format!("{file} can not be written ({error})")
+            RunnerError::FileReadAccess { path } => {
+                format!("file {} can not be read", path.to_string_lossy())
+            }
+            RunnerError::FileWriteAccess { path, error } => {
+                format!("{} can not be written ({error})", path.to_string_lossy())
             }
             RunnerError::FilterDecode(encoding) => {
                 format!("value can not be decoded with <{encoding}> encoding")
@@ -213,10 +212,8 @@ impl hurl_core::error::Error for Error {
                 format!("actual value is <{value}>")
             }
             RunnerError::InvalidRegex => "regex expression is not valid".to_string(),
-            RunnerError::InvalidUrl(url) => format!("invalid URL <{url}>"),
-            RunnerError::InvalidUrlPrefix(url) => {
-                format!("URL <{url}> must start with http:// or https://")
-            }
+            RunnerError::InvalidUrl(url, reason) => format!("invalid URL <{url}> ({reason})"),
+
             RunnerError::NoQueryResult => "The query didn't return any result".to_string(),
             RunnerError::QueryHeaderNotFound => {
                 "this header has not been found in the response".to_string()
@@ -239,7 +236,7 @@ impl hurl_core::error::Error for Error {
             RunnerError::UnauthorizedFileAccess { path } => {
                 format!(
                     "unauthorized access to file {}, check --file-root option",
-                    path.to_str().unwrap()
+                    path.to_string_lossy()
                 )
             }
             RunnerError::UnrenderableVariable { name, value } => {
@@ -253,20 +250,29 @@ impl hurl_core::error::Error for Error {
             }
         }
     }
+
+    fn show_source_line(&self) -> bool {
+        true
+    }
+
+    fn show_caret(&self) -> bool {
+        !matches!(&self.inner, RunnerError::AssertFailure { .. })
+    }
 }
 
 impl From<HttpError> for RunnerError {
     /// Converts a HttpError to a RunnerError.
     fn from(item: HttpError) -> Self {
         match item {
-            HttpError::CouldNotParseResponse => RunnerError::CouldNotParseResponse,
+            HttpError::CouldNotParseResponse => {
+                RunnerError::HttpConnection("could not parse Response".to_string())
+            }
             HttpError::CouldNotUncompressResponse { description } => {
                 RunnerError::CouldNotUncompressResponse(description)
             }
             HttpError::InvalidCharset { charset } => RunnerError::InvalidCharset { charset },
             HttpError::InvalidDecoding { charset } => RunnerError::InvalidDecoding { charset },
-            HttpError::InvalidUrl(url) => RunnerError::InvalidUrl(url),
-            HttpError::InvalidUrlPrefix(url) => RunnerError::InvalidUrlPrefix(url),
+            HttpError::InvalidUrl(url, reason) => RunnerError::InvalidUrl(url, reason),
             HttpError::Libcurl { code, description } => {
                 RunnerError::HttpConnection(format!("({code}) {description}"))
             }
