@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,24 +16,29 @@
  *
  */
 use std::collections::HashMap;
-use std::path::PathBuf;
 use std::thread;
 use std::time::Instant;
 
 use chrono::Utc;
 use hurl_core::ast::VersionValue::VersionAnyLegacy;
-use hurl_core::ast::{Body, Bytes, Entry, HurlFile, MultilineString, Request, Response, Retry};
+use hurl_core::ast::{Body, Bytes, Entry, MultilineString, Request, Response, Retry};
 use hurl_core::error::Error;
 use hurl_core::parser;
 
-use crate::http::Call;
+use crate::http::{Call, Client};
+use crate::runner::event::EventListener;
+use crate::runner::progress::{Mode, SeqProgress};
 use crate::runner::runner_options::RunnerOptions;
-use crate::runner::{entry, options, EntryResult, HurlResult, RunnerError, Value};
-use crate::util::logger::{ErrorFormat, Logger, LoggerOptions, LoggerOptionsBuilder};
-use crate::{http, runner};
+use crate::runner::{entry, options, EntryResult, HurlResult, Value};
+use crate::util::logger::{ErrorFormat, Logger, LoggerOptions};
+use crate::util::term::{Stderr, Stdout, WriteMode};
 
 /// Runs a Hurl `content` and returns a [`HurlResult`] upon completion.
 ///
+/// If `content` is a syntactically correct Hurl file, an [`HurlResult`] is always returned on
+/// run completion. The success or failure of the run (due to assertions checks, runtime failures
+/// etc..) can be read in the [`HurlResult`] `success` field. If `content` is not syntactically
+/// correct, a parsing error is returned. This is the only possible way for this function to fail.
 ///
 /// # Example
 ///
@@ -76,34 +81,90 @@ pub fn run(
     variables: &HashMap<String, Value>,
     logger_options: &LoggerOptions,
 ) -> Result<HurlResult, String> {
-    let logger = Logger::from(logger_options);
+    // In this method, we run Hurl content sequentially. Standard output and standard error messages
+    // are written immediately (in parallel mode, we'll use buffered standard output and error).
+    let mut stdout = Stdout::new(WriteMode::Immediate);
+    let stderr = Stderr::new(WriteMode::Immediate);
+
+    // We also create a common logger for this run (logger verbosity can eventually be mutated on
+    // each entry).
+    let mut logger = Logger::new(logger_options, stderr);
+
+    // Create a progress bar for the sequential run, progress will be report in the main thread,
+    // as soon as an entry is executed.
+    let filename = &logger_options.filename;
+    let current_file = logger_options.current_file;
+    let total_files = logger_options.total_files;
+    let test = logger_options.test;
+    let color = logger_options.color;
+    let progress_bar = logger_options.progress_bar;
+    let progress = SeqProgress::new(
+        filename,
+        current_file,
+        total_files,
+        Mode::new(test, progress_bar),
+        color,
+    );
+
+    progress.print_test_start(&mut logger.stderr);
 
     // Try to parse the content
     let hurl_file = parser::parse_hurl_file(content);
     let hurl_file = match hurl_file {
         Ok(h) => h,
         Err(e) => {
-            logger.error_rich(content, &e);
+            logger.error_parsing_rich(content, &e);
             return Err(e.description());
         }
     };
 
-    log_run_info(&hurl_file, runner_options, variables, &logger);
-
     // Now, we have a syntactically correct HurlFile instance, we can run it.
-    let mut http_client = http::Client::new();
-    let mut entries = vec![];
+    let result = run_entries(
+        &hurl_file.entries,
+        content,
+        runner_options,
+        variables,
+        &mut stdout,
+        &progress,
+        &mut logger,
+    );
+
+    if result.success && result.entries.last().is_none() {
+        logger.warning(&format!("No entry have been executed for file {filename}"));
+    }
+
+    progress.print_test_completed(&result, &mut logger.stderr);
+
+    Ok(result)
+}
+
+/// Runs a list of `entries` and returns a [`HurlResult`] upon completion.
+///
+/// `content` is the original source content, used to construct `entries`. It is used to construct
+/// rich error messages with annotated source code.
+/// New entry run events are reported to `progress` and are usually used to display a progress bar
+/// in test mode.
+pub fn run_entries(
+    entries: &[Entry],
+    content: &str,
+    runner_options: &RunnerOptions,
+    variables: &HashMap<String, Value>,
+    stdout: &mut Stdout,
+    listener: &dyn EventListener,
+    logger: &mut Logger,
+) -> HurlResult {
+    let mut http_client = Client::new();
+    let mut entries_result = vec![];
     let mut variables = variables.clone();
-    let mut entry_index = 1;
+    let mut entry_index = runner_options.from_entry.unwrap_or(1);
+    let n = runner_options.to_entry.unwrap_or(entries.len());
     let mut retry_count = 1;
-    let n = if let Some(to_entry) = runner_options.to_entry {
-        to_entry
-    } else {
-        hurl_file.entries.len()
-    };
+    let default_verbosity = logger.verbosity;
     let start = Instant::now();
     let timestamp = Utc::now().timestamp();
 
+    log_run_info(entries, runner_options, &variables, logger);
+
     // Main loop processing each entry.
     // The `entry_index` is not always incremented of each loop tick: an entry can be retried upon
     // errors for instance. Each entry is executed with options that are computed from the global
@@ -112,13 +173,8 @@ pub fn run(
         if entry_index > n {
             break;
         }
-        let entry = &hurl_file.entries[entry_index - 1];
+        let entry = &entries[entry_index - 1];
 
-        // We compute the new logger for this entry, before entering into the `run` function because
-        // entry options can modify the logger and we want the preamble "Executing entry..." to be
-        // displayed based on the entry level verbosity.
-        let logger =
-            get_entry_logger(entry, logger_options, &variables).map_err(|e| e.description())?;
         if let Some(pre_entry) = runner_options.pre_entry {
             let exit = pre_entry(entry.clone());
             if exit {
@@ -126,23 +182,37 @@ pub fn run(
             }
         }
 
+        // We compute the new logger verbosity for this entry, before entering into the `run`
+        // function because entry options can modify the logger verbosity and we want the preamble
+        // "Executing entry..." to be displayed based on the entry level verbosity.
+        logger.verbosity = default_verbosity;
+        let entry_verbosity = options::get_entry_verbosity(entry, default_verbosity, &variables);
+        if let Ok(entry_verbosity) = entry_verbosity {
+            logger.verbosity = entry_verbosity;
+        }
+
         logger.debug_important(
             "------------------------------------------------------------------------------",
         );
-        logger.debug_important(format!("Executing entry {entry_index}").as_str());
+        logger.debug_important(&format!("Executing entry {entry_index}"));
 
-        warn_deprecated(entry, &logger);
+        warn_deprecated(entry, logger);
 
-        logger.test_progress(entry_index, n);
+        listener.on_running(entry_index - 1, n, &mut logger.stderr);
 
         // The real execution of the entry happens here, with the overridden entry options.
-        let options = options::get_entry_options(entry, runner_options, &mut variables, &logger);
+        let options = options::get_entry_options(entry, runner_options, &mut variables, logger);
         let entry_result = match &options {
+            Err(error) => EntryResult {
+                entry_index,
+                source_info: entry.source_info(),
+                errors: vec![error.clone()],
+                ..Default::default()
+            },
             Ok(options) => {
                 if options.skip {
-                    logger
-                        .debug_important(format!("Entry {entry_index} has been skipped").as_str());
                     logger.debug("");
+                    logger.debug_important(&format!("Entry {entry_index} has been skipped"));
                     entry_index += 1;
                     continue;
                 }
@@ -151,10 +221,9 @@ pub fn run(
                 let delay_ms = delay.as_millis();
                 if delay_ms > 0 {
                     logger.debug("");
-                    logger.debug_important(
-                        format!("Delay entry {entry_index} (x{retry_count} by {delay_ms} ms)")
-                            .as_str(),
-                    );
+                    logger.debug_important(&format!(
+                        "Delay entry {entry_index} (x{retry_count} by {delay_ms} ms)"
+                    ));
                     thread::sleep(delay);
                 };
 
@@ -164,19 +233,9 @@ pub fn run(
                     &mut http_client,
                     &mut variables,
                     options,
-                    &logger,
+                    logger,
                 )
             }
-            Err(error) => EntryResult {
-                entry_index,
-                source_info: entry.source_info(),
-                calls: vec![],
-                captures: vec![],
-                asserts: vec![],
-                errors: vec![error.clone()],
-                time_in_ms: 0,
-                compressed: false,
-            },
         };
 
         // Check if we need to retry.
@@ -195,7 +254,6 @@ pub fn run(
         // error so any potential error is the last thing displayed to the user.
         // If `retry_max_reached` is not true (for instance `retry`is true, or there is no error
         // we first log the error and a potential warning about retrying.
-        logger.test_erase_line();
         if retry_max_reached {
             logger.debug_important("Retry max count reached, no more retry");
             logger.debug("");
@@ -204,10 +262,10 @@ pub fn run(
         // We logs eventual errors, only if we're not retrying the current entry...
         let retry = !matches!(retry_opts, Retry::None) && !retry_max_reached && has_error;
         if has_error {
-            log_errors(&entry_result, content, retry, &logger);
+            log_errors(&entry_result, content, retry, logger);
         }
 
-        // When --output is overriden on a request level, we output the HTTP response only if the
+        // When --output is overridden on a request level, we output the HTTP response only if the
         // call has succeeded.
         if let Ok(RunnerOptions {
             output: Some(output),
@@ -220,32 +278,30 @@ pub fn run(
                 // an error. If we want to treat it as an error, we've to add it to the current
                 // `entry_result` errors, and optionally deals with retry if we can't write to the
                 // specified path.
-                if !runner_options.context_dir.is_access_allowed(&output) {
-                    let inner = RunnerError::UnauthorizedFileAccess {
-                        path: PathBuf::from(output.clone()),
-                    };
-                    let error = runner::Error::new(entry.request.source_info, inner, false);
-                    logger.warning(&error.fixme());
-                } else if let Err(error) = entry_result.write_response(output) {
+                let source_info = entry.source_info();
+                if let Err(error) = entry_result.write_response(
+                    &output,
+                    &runner_options.context_dir,
+                    stdout,
+                    source_info,
+                ) {
                     logger.warning(&error.fixme());
                 }
             }
         }
-        entries.push(entry_result);
+        entries_result.push(entry_result);
 
         if retry {
             let delay = retry_interval.as_millis();
             logger.debug("");
-            logger.debug_important(
-                format!("Retry entry {entry_index} (x{retry_count} pause {delay} ms)").as_str(),
-            );
+            logger.debug_important(&format!(
+                "Retry entry {entry_index} (x{retry_count} pause {delay} ms)"
+            ));
             retry_count += 1;
             // If we retry the entry, we do not want to display a 'blank' progress bar during the
             // sleep delay. During the pause, we artificially show the previously erased progress
             // line.
-            logger.test_progress(entry_index, n);
             thread::sleep(retry_interval);
-            logger.test_erase_line();
             continue;
         }
 
@@ -266,22 +322,29 @@ pub fn run(
 
     let time_in_ms = start.elapsed().as_millis();
     let cookies = http_client.get_cookie_storage();
-    let success = is_success(&entries);
-    Ok(HurlResult {
-        entries,
+    let success = is_success(&entries_result);
+    HurlResult {
+        entries: entries_result,
         time_in_ms,
         success,
         cookies,
         timestamp,
-    })
+    }
 }
 
-/// Returns `true` if all the entries ar successful, `false` otherwise.
+/// Returns `true` if all the entries results are successful, `false` otherwise.
+///
+/// For a given list of entry results, only the last one on the same index is checked.
 ///
-/// For a given list of entry, only the last one on the same index is checked.
 /// For instance:
-/// entry a:1, entry b:1, entry c:2, entry d:3, entry e:3
-/// Only the entry b, c and e are checked for the success state.
+///
+/// - `entry result a`: `entry index 1` (retried)
+/// - `entry result b`: `entry index 1`
+/// - `entry result c`: `entry index 2`
+/// - `entry result d`: `entry index 3` (retried)
+/// - `entry result e`: `entry index 3`
+///
+/// Only the entry result b, c and e are checked for the success state.
 fn is_success(entries: &[EntryResult]) -> bool {
     let mut next_entries = entries.iter().skip(1);
     for entry in entries.iter() {
@@ -298,7 +361,7 @@ fn is_success(entries: &[EntryResult]) -> bool {
 }
 
 /// Logs deprecated syntax and provides alternatives.
-fn warn_deprecated(entry: &Entry, logger: &Logger) {
+fn warn_deprecated(entry: &Entry, logger: &mut Logger) {
     // HTTP/* is used instead of HTTP.
     if let Some(response) = &entry.response {
         let filename = &logger.filename;
@@ -307,12 +370,7 @@ fn warn_deprecated(entry: &Entry, logger: &Logger) {
         let line = &source_info.start.line;
         let column = &source_info.start.column;
         if version.value == VersionAnyLegacy {
-            logger.warning(
-                format!(
-                    "{filename}:{line}:{column} 'HTTP/*' keyword is deprecated, please use 'HTTP' instead"
-                )
-                .as_str(),
-            );
+            logger.warning(&format!("{filename}:{line}:{column} 'HTTP/*' keyword is deprecated, please use 'HTTP' instead"));
         }
     }
 
@@ -331,12 +389,7 @@ fn warn_deprecated(entry: &Entry, logger: &Logger) {
         let line = &source_info.start.line;
         let column = &source_info.start.column;
         let template = template.to_string();
-        logger.warning(
-            format!(
-                "{filename}:{line}:{column} '```{template}```' request body is deprecated, please use '`{template}`' instead"
-            )
-            .as_str(),
-        );
+        logger.warning(&format!("{filename}:{line}:{column} '```{template}```' request body is deprecated, please use '`{template}`' instead"));
     }
 
     if let Some(Response {
@@ -406,7 +459,7 @@ fn get_non_default_options(options: &RunnerOptions) -> Vec<(&'static str, String
 
     if options.unix_socket != default_options.unix_socket {
         if let Some(unix_socket) = &options.unix_socket {
-            non_default_options.push(("unix socket", unix_socket.to_string()))
+            non_default_options.push(("unix socket", unix_socket.to_string()));
         }
     }
 
@@ -415,17 +468,17 @@ fn get_non_default_options(options: &RunnerOptions) -> Vec<(&'static str, String
 
 /// Logs various debug information at the start of `hurl_file` run.
 fn log_run_info(
-    hurl_file: &HurlFile,
+    entries: &[Entry],
     runner_options: &RunnerOptions,
     variables: &HashMap<String, Value>,
-    logger: &Logger,
+    logger: &mut Logger,
 ) {
     if logger.verbosity.is_some() {
         let non_default_options = get_non_default_options(runner_options);
         if !non_default_options.is_empty() {
             logger.debug_important("Options:");
             for (name, value) in non_default_options.iter() {
-                logger.debug(format!("    {name}: {value}").as_str());
+                logger.debug(&format!("    {name}: {value}"));
             }
         }
     }
@@ -433,59 +486,34 @@ fn log_run_info(
     if !variables.is_empty() {
         logger.debug_important("Variables:");
         for (name, value) in variables.iter() {
-            logger.debug(format!("    {name}: {value}").as_str());
+            logger.debug(&format!("    {name}: {value}"));
         }
     }
     if let Some(to_entry) = runner_options.to_entry {
-        logger
-            .debug(format!("Executing {}/{} entries", to_entry, hurl_file.entries.len()).as_str());
+        logger.debug(&format!("Executing {to_entry}/{} entries", entries.len()));
     }
 }
 
 /// Logs runner `errors`.
 /// If we're going to `retry` the entry, we log errors only in verbose. Otherwise, we log error on stderr.
-fn log_errors(entry_result: &EntryResult, content: &str, retry: bool, logger: &Logger) {
+fn log_errors(entry_result: &EntryResult, content: &str, retry: bool, logger: &mut Logger) {
     if retry {
         entry_result
             .errors
             .iter()
-            .for_each(|e| logger.debug_error(content, e));
+            .for_each(|e| logger.debug_error(content, e, entry_result.source_info));
         return;
     }
 
     if logger.error_format == ErrorFormat::Long {
         if let Some(Call { response, .. }) = entry_result.calls.last() {
-            response.log_all(logger);
-        } else {
-            logger.info("<No HTTP response>");
-            logger.info("");
+            response.log_info_all(logger);
         }
     }
     entry_result
         .errors
         .iter()
-        .for_each(|e| logger.error_rich(content, e));
-}
-
-/// Creates a new logger for this entry.
-/// Verbosity can be overridden at entry level with an Options section so each
-/// entry has its own logger.
-fn get_entry_logger(
-    entry: &Entry,
-    logger_options: &LoggerOptions,
-    variables: &HashMap<String, Value>,
-) -> Result<Logger, runner::Error> {
-    let entry_verbosity =
-        options::get_entry_verbosity(entry, &logger_options.verbosity, variables)?;
-    let entry_logger_options = LoggerOptionsBuilder::new()
-        .color(logger_options.color)
-        .filename(&logger_options.filename)
-        .error_format(logger_options.error_format)
-        .progress_bar(entry_verbosity.is_none() && logger_options.progress_bar)
-        .verbosity(entry_verbosity)
-        .test(logger_options.test)
-        .build();
-    Ok(Logger::from(&entry_logger_options))
+        .for_each(|error| logger.error_runtime_rich(content, error, entry_result.source_info));
 }
 
 #[cfg(test)]
@@ -508,7 +536,7 @@ mod test {
         let non_default_options = get_non_default_options(&options);
         assert_eq!(non_default_options.len(), 1);
 
-        let first_non_default = non_default_options.get(0).unwrap();
+        let first_non_default = non_default_options.first().unwrap();
 
         assert_eq!(first_non_default.0, "delay");
         assert_eq!(first_non_default.1, "500ms");
