@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,7 +19,12 @@
 //! A runner for Hurl files. If you want to execute an Hurl file, this is the right place.
 
 pub use self::error::{Error, RunnerError};
+#[doc(hidden)]
+pub use self::event::EventListener;
 pub use self::hurl_file::run;
+#[doc(hidden)]
+pub use self::hurl_file::run_entries;
+pub use self::input::Input;
 pub use self::number::Number;
 pub use self::output::Output;
 pub use self::result::{AssertResult, CaptureResult, EntryResult, HurlResult};
@@ -31,9 +36,11 @@ mod body;
 mod capture;
 mod entry;
 mod error;
+mod event;
 mod expr;
 mod filter;
 mod hurl_file;
+mod input;
 mod json;
 mod multiline;
 mod multipart;
@@ -42,6 +49,7 @@ mod options;
 mod output;
 mod predicate;
 mod predicate_value;
+mod progress;
 mod query;
 mod regex;
 mod request;
