@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@ use hurl_core::ast::{
 
 use crate::http::{IpResolve, RequestedHttpVersion};
 use crate::runner::template::{eval_expression, eval_template};
-use crate::runner::{Error, Number, RunnerError, RunnerOptions, Value};
+use crate::runner::{Error, Number, Output, RunnerError, RunnerOptions, Value};
 use crate::util::logger::{Logger, Verbosity};
 
 /// Returns a new [`RunnerOptions`] based on the `entry` optional Options section
@@ -35,9 +35,16 @@ pub fn get_entry_options(
     entry: &Entry,
     runner_options: &RunnerOptions,
     variables: &mut HashMap<String, Value>,
-    logger: &Logger,
+    logger: &mut Logger,
 ) -> Result<RunnerOptions, Error> {
-    let mut runner_options = runner_options.clone();
+    let runner_options = runner_options.clone();
+    // When used globally (on the command line), `--output` writes the last successful request
+    // to `output` file. We don't want to output every entry's response, so we initialise
+    // output to `None`.
+    let mut runner_options = RunnerOptions {
+        output: None,
+        ..runner_options
+    };
     if !has_options(entry) {
         return Ok(runner_options);
     }
@@ -51,31 +58,31 @@ pub fn get_entry_options(
                 match &option.kind {
                     OptionKind::AwsSigV4(value) => {
                         let value = eval_template(value, variables)?;
-                        runner_options.aws_sigv4 = Some(value)
+                        runner_options.aws_sigv4 = Some(value);
                     }
                     OptionKind::CaCertificate(filename) => {
                         let value = eval_template(filename, variables)?;
-                        runner_options.cacert_file = Some(value)
+                        runner_options.cacert_file = Some(value);
                     }
                     OptionKind::ClientCert(filename) => {
                         let value = eval_template(filename, variables)?;
-                        runner_options.client_cert_file = Some(value)
+                        runner_options.client_cert_file = Some(value);
                     }
                     OptionKind::ClientKey(filename) => {
                         let value = eval_template(filename, variables)?;
-                        runner_options.client_key_file = Some(value)
+                        runner_options.client_key_file = Some(value);
                     }
                     OptionKind::Compressed(value) => {
                         let value = eval_boolean_option(value, variables)?;
-                        runner_options.compressed = value
+                        runner_options.compressed = value;
                     }
                     OptionKind::ConnectTo(value) => {
                         let value = eval_template(value, variables)?;
-                        runner_options.connects_to.push(value)
+                        runner_options.connects_to.push(value);
                     }
                     OptionKind::Delay(value) => {
                         let value = eval_natural_option(value, variables)?;
-                        runner_options.delay = Duration::from_millis(value)
+                        runner_options.delay = Duration::from_millis(value);
                     }
                     // HTTP version options (such as http1.0, http1.1, http2 etc...) are activated
                     // through a flag. In an `[Options]` section, the signification of such a flag is:
@@ -104,31 +111,31 @@ pub fn get_entry_options(
                     OptionKind::Http10(value) => {
                         let value = eval_boolean_option(value, variables)?;
                         if value {
-                            runner_options.http_version = RequestedHttpVersion::Http10
+                            runner_options.http_version = RequestedHttpVersion::Http10;
                         }
                     }
                     OptionKind::Http11(value) => {
                         let value = eval_boolean_option(value, variables)?;
                         if value {
-                            runner_options.http_version = RequestedHttpVersion::Http11
+                            runner_options.http_version = RequestedHttpVersion::Http11;
                         } else {
-                            runner_options.http_version = RequestedHttpVersion::Http10
+                            runner_options.http_version = RequestedHttpVersion::Http10;
                         }
                     }
                     OptionKind::Http2(value) => {
                         let value = eval_boolean_option(value, variables)?;
                         if value {
-                            runner_options.http_version = RequestedHttpVersion::Http2
+                            runner_options.http_version = RequestedHttpVersion::Http2;
                         } else {
-                            runner_options.http_version = RequestedHttpVersion::Http11
+                            runner_options.http_version = RequestedHttpVersion::Http11;
                         }
                     }
                     OptionKind::Http3(value) => {
                         let value = eval_boolean_option(value, variables)?;
                         if value {
-                            runner_options.http_version = RequestedHttpVersion::Http3
+                            runner_options.http_version = RequestedHttpVersion::Http3;
                         } else {
-                            runner_options.http_version = RequestedHttpVersion::Http2
+                            runner_options.http_version = RequestedHttpVersion::Http2;
                         }
                     }
                     OptionKind::FollowLocation(value) => {
@@ -144,7 +151,7 @@ pub fn get_entry_options(
                     }
                     OptionKind::Insecure(value) => {
                         let value = eval_boolean_option(value, variables)?;
-                        runner_options.insecure = value
+                        runner_options.insecure = value;
                     }
                     OptionKind::IpV4(value) => {
                         let value = eval_boolean_option(value, variables)?;
@@ -164,48 +171,70 @@ pub fn get_entry_options(
                     }
                     OptionKind::MaxRedirect(value) => {
                         let value = eval_natural_option(value, variables)?;
-                        runner_options.max_redirect = Some(value as usize)
+                        runner_options.max_redirect = Some(value as usize);
                     }
-                    OptionKind::Output(filename) => {
-                        let value = eval_template(filename, variables)?;
-                        runner_options.output = Some(value)
+                    OptionKind::NetRc(value) => {
+                        let value = eval_boolean_option(value, variables)?;
+                        runner_options.netrc = value;
+                    }
+                    OptionKind::NetRcFile(value) => {
+                        let filename = eval_template(value, variables)?;
+                        runner_options.netrc_file = Some(filename);
+                    }
+                    OptionKind::NetRcOptional(value) => {
+                        let value = eval_boolean_option(value, variables)?;
+                        runner_options.netrc_optional = value;
+                    }
+                    OptionKind::Output(output) => {
+                        let filename = eval_template(output, variables)?;
+                        let output = Output::new(&filename);
+                        runner_options.output = Some(output);
                     }
                     OptionKind::PathAsIs(value) => {
                         let value = eval_boolean_option(value, variables)?;
-                        runner_options.path_as_is = value
+                        runner_options.path_as_is = value;
                     }
                     OptionKind::Proxy(value) => {
                         let value = eval_template(value, variables)?;
-                        runner_options.proxy = Some(value.to_string())
+                        runner_options.proxy = Some(value);
                     }
                     OptionKind::Resolve(value) => {
                         let value = eval_template(value, variables)?;
-                        runner_options.resolves.push(value)
+                        runner_options.resolves.push(value);
                     }
                     OptionKind::Retry(value) => {
                         let value = eval_retry_option(value, variables)?;
-                        runner_options.retry = value
+                        runner_options.retry = value;
                     }
                     OptionKind::RetryInterval(value) => {
                         let value = eval_natural_option(value, variables)?;
-                        runner_options.retry_interval = Duration::from_millis(value)
+                        runner_options.retry_interval = Duration::from_millis(value);
                     }
                     OptionKind::Skip(value) => {
                         let value = eval_boolean_option(value, variables)?;
-                        runner_options.skip = value
+                        runner_options.skip = value;
                     }
                     OptionKind::UnixSocket(value) => {
                         let value = eval_template(value, variables)?;
-                        runner_options.unix_socket = Some(value.to_string())
+                        runner_options.unix_socket = Some(value);
+                    }
+                    OptionKind::User(value) => {
+                        let value = eval_template(value, variables)?;
+                        runner_options.user = Some(value);
                     }
                     OptionKind::Variable(VariableDefinition { name, value, .. }) => {
                         let value = eval_variable_value(value, variables)?;
                         variables.insert(name.clone(), value);
                     }
-                    // verbose and very-verbose option have been previously processed as thy
-                    // can impact the logging.
-                    OptionKind::Verbose(_) => {}
-                    OptionKind::VeryVerbose(_) => {}
+                    // verbose and very-verbose option have been previously processed as they
+                    // can impact the logging. We compute here their values to check the potential
+                    // templatized error.
+                    OptionKind::Verbose(value) => {
+                        eval_boolean_option(value, variables)?;
+                    }
+                    OptionKind::VeryVerbose(value) => {
+                        eval_boolean_option(value, variables)?;
+                    }
                 }
                 log_option(option, logger);
             }
@@ -215,7 +244,7 @@ pub fn get_entry_options(
 }
 
 /// Logs an entry option.
-fn log_option(option: &EntryOption, logger: &Logger) {
+fn log_option(option: &EntryOption, logger: &mut Logger) {
     let name = option.kind.name();
     let value = option.kind.value_as_str();
     logger.debug(&format!("{name}: {value}"));
@@ -233,10 +262,10 @@ fn has_options(entry: &Entry) -> bool {
 /// Returns the overridden `entry` verbosity, or the default `verbosity` file.
 pub fn get_entry_verbosity(
     entry: &Entry,
-    verbosity: &Option<Verbosity>,
+    default_verbosity: Option<Verbosity>,
     variables: &HashMap<String, Value>,
 ) -> Result<Option<Verbosity>, Error> {
-    let mut verbosity = *verbosity;
+    let mut verbosity = default_verbosity;
 
     for section in &entry.request.sections {
         if let SectionValue::Options(options) = &section.value {
