@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,5 +15,8 @@
  * limitations under the License.
  *
  */
+pub use bar::progress_bar;
+mod bar;
 pub mod logger;
 pub mod path;
+pub mod term;
