@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -490,8 +490,10 @@ pub enum PredicateFuncValue {
     IsString,
     IsCollection,
     IsDate,
+    IsIsoDate,
     Exist,
     IsEmpty,
+    IsNumber,
 }
 
 //
@@ -728,6 +730,9 @@ pub enum OptionKind {
     FollowLocation(BooleanOption),
     FollowLocationTrusted(BooleanOption),
     MaxRedirect(NaturalOption),
+    NetRc(BooleanOption),
+    NetRcFile(Template),
+    NetRcOptional(BooleanOption),
     Output(Template),
     PathAsIs(BooleanOption),
     Proxy(Template),
@@ -736,6 +741,7 @@ pub enum OptionKind {
     RetryInterval(NaturalOption),
     Skip(BooleanOption),
     UnixSocket(Template),
+    User(Template),
     Variable(VariableDefinition),
     Verbose(BooleanOption),
     VeryVerbose(BooleanOption),
@@ -761,6 +767,9 @@ impl OptionKind {
             OptionKind::IpV4(_) => "ipv4",
             OptionKind::IpV6(_) => "ipv6",
             OptionKind::MaxRedirect(_) => "max-redirs",
+            OptionKind::NetRc(_) => "netrc",
+            OptionKind::NetRcFile(_) => "netrc-file",
+            OptionKind::NetRcOptional(_) => "netrc-optional",
             OptionKind::Output(_) => "output",
             OptionKind::PathAsIs(_) => "path-as-is",
             OptionKind::Proxy(_) => "proxy",
@@ -769,6 +778,7 @@ impl OptionKind {
             OptionKind::RetryInterval(_) => "retry-interval",
             OptionKind::Skip(_) => "skip",
             OptionKind::UnixSocket(_) => "unix-socket",
+            OptionKind::User(_) => "user",
             OptionKind::Variable(_) => "variable",
             OptionKind::Verbose(_) => "verbose",
             OptionKind::VeryVerbose(_) => "very-verbose",
@@ -794,6 +804,9 @@ impl OptionKind {
             OptionKind::IpV4(value) => value.to_string(),
             OptionKind::IpV6(value) => value.to_string(),
             OptionKind::MaxRedirect(value) => value.to_string(),
+            OptionKind::NetRc(value) => value.to_string(),
+            OptionKind::NetRcFile(filename) => filename.to_string(),
+            OptionKind::NetRcOptional(value) => value.to_string(),
             OptionKind::Output(filename) => filename.to_string(),
             OptionKind::PathAsIs(value) => value.to_string(),
             OptionKind::Proxy(value) => value.to_string(),
@@ -802,6 +815,7 @@ impl OptionKind {
             OptionKind::RetryInterval(value) => value.to_string(),
             OptionKind::Skip(value) => value.to_string(),
             OptionKind::UnixSocket(value) => value.to_string(),
+            OptionKind::User(value) => value.to_string(),
             OptionKind::Variable(VariableDefinition { name, value, .. }) => {
                 format!("{name}={value}")
             }
