@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -270,8 +270,10 @@ impl PredicateFuncValue {
             PredicateFuncValue::IsString => "isString".to_string(),
             PredicateFuncValue::IsCollection => "isCollection".to_string(),
             PredicateFuncValue::IsDate => "isDate".to_string(),
+            PredicateFuncValue::IsIsoDate => "isIsoDate".to_string(),
             PredicateFuncValue::Exist => "exists".to_string(),
             PredicateFuncValue::IsEmpty => "isEmpty".to_string(),
+            PredicateFuncValue::IsNumber => "isNumber".to_string(),
         }
     }
 }
