@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,4 +21,6 @@ pub trait Error {
     fn source_info(&self) -> SourceInfo;
     fn description(&self) -> String;
     fn fixme(&self) -> String;
+    fn show_source_line(&self) -> bool;
+    fn show_caret(&self) -> bool;
 }
