@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -177,17 +177,17 @@ impl HtmlFormatter {
             SectionValue::QueryParams(items) => items.iter().for_each(|item| self.fmt_kv(item)),
             SectionValue::BasicAuth(item) => {
                 if let Some(kv) = item {
-                    self.fmt_kv(kv)
+                    self.fmt_kv(kv);
                 }
             }
             SectionValue::FormParams(items) => items.iter().for_each(|item| self.fmt_kv(item)),
             SectionValue::MultipartFormData(items) => {
-                items.iter().for_each(|item| self.fmt_multipart_param(item))
+                items.iter().for_each(|item| self.fmt_multipart_param(item));
             }
             SectionValue::Cookies(items) => items.iter().for_each(|item| self.fmt_cookie(item)),
             SectionValue::Captures(items) => items.iter().for_each(|item| self.fmt_capture(item)),
             SectionValue::Options(items) => {
-                items.iter().for_each(|item| self.fmt_entry_option(item))
+                items.iter().for_each(|item| self.fmt_entry_option(item));
             }
         }
     }
@@ -231,6 +231,9 @@ impl HtmlFormatter {
             OptionKind::IpV4(value) => self.fmt_bool_option(value),
             OptionKind::IpV6(value) => self.fmt_bool_option(value),
             OptionKind::MaxRedirect(value) => self.fmt_natural_option(value),
+            OptionKind::NetRc(value) => self.fmt_bool_option(value),
+            OptionKind::NetRcFile(filename) => self.fmt_filename(filename),
+            OptionKind::NetRcOptional(value) => self.fmt_bool_option(value),
             OptionKind::Output(filename) => self.fmt_filename(filename),
             OptionKind::PathAsIs(value) => self.fmt_bool_option(value),
             OptionKind::Proxy(value) => self.fmt_template(value),
@@ -239,6 +242,7 @@ impl HtmlFormatter {
             OptionKind::RetryInterval(value) => self.fmt_natural_option(value),
             OptionKind::Skip(value) => self.fmt_bool_option(value),
             OptionKind::UnixSocket(value) => self.fmt_template(value),
+            OptionKind::User(value) => self.fmt_template(value),
             OptionKind::Variable(value) => self.fmt_variable_definition(value),
             OptionKind::Verbose(value) => self.fmt_bool_option(value),
             OptionKind::VeryVerbose(value) => self.fmt_bool_option(value),
@@ -526,8 +530,10 @@ impl HtmlFormatter {
             PredicateFuncValue::IsString => {}
             PredicateFuncValue::IsCollection => {}
             PredicateFuncValue::IsDate => {}
+            PredicateFuncValue::IsIsoDate => {}
             PredicateFuncValue::Exist => {}
             PredicateFuncValue::IsEmpty => {}
+            PredicateFuncValue::IsNumber => {}
         }
     }
 
@@ -629,7 +635,7 @@ impl HtmlFormatter {
             self.fmt_span("multiline", &tail);
             // As we have added a span close, we must remove one to have the right number
             // of span. The current span line will add a closing span.
-            pop_str(&mut self.buffer, "</span>")
+            pop_str(&mut self.buffer, "</span>");
         }
     }
 
@@ -837,7 +843,7 @@ impl HtmlFormatter {
         for line_terminator in line_terminators {
             self.fmt_span_open("line");
             if line_terminator.newline.value.is_empty() {
-                self.buffer.push_str("<br>");
+                self.buffer.push_str("<br />");
             }
             self.fmt_span_close();
             self.fmt_lt(line_terminator);
@@ -862,7 +868,7 @@ impl Template {
                 TemplateElement::String { encoded, .. } => encoded.to_string(),
                 TemplateElement::Expression(expr) => format!("{{{{{expr}}}}}"),
             };
-            s.push_str(elem_str.as_str())
+            s.push_str(elem_str.as_str());
         }
         if let Some(d) = self.delimiter {
             s.push(d);
@@ -1062,7 +1068,7 @@ mod tests {
         assert_eq!(
             fmt.buffer,
             "<span class=\"json\"><span class=\"line\">\"\\n\"</span></span>"
-        )
+        );
     }
 
     #[test]
@@ -1073,7 +1079,7 @@ mod tests {
         assert_eq!(
             fmt.buffer,
             "<span class=\"xml\"><span class=\"line\">&lt;?xml version=\"1.0\"?&gt;</span>\n<span class=\"line\">&lt;drink&gt;café&lt;/drink&gt;</span></span>"
-        )
+        );
     }
 
     #[test]
