@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -235,6 +235,14 @@ impl crate::error::Error for Error {
             ParseError::Xml => "invalid XML".to_string(),
         }
     }
+
+    fn show_source_line(&self) -> bool {
+        true
+    }
+
+    fn show_caret(&self) -> bool {
+        true
+    }
 }
 
 fn did_you_mean(valid_values: &[&str], actual: &str, default: &str) -> String {
