@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -386,14 +386,14 @@ mod tests {
 
     #[test]
     fn test_multiline_string_failed() {
-        let datas = [
+        let data = [
             "```hexaaa\nline1\nline2\nline3\n```",
             "```aaa\nline1\nline2\nline3\n```",
         ];
 
-        for text in datas.iter() {
+        for text in data.iter() {
             let mut reader = Reader::new(text);
-            assert!(multiline_string(&mut reader).is_err())
+            assert!(multiline_string(&mut reader).is_err());
         }
     }
 
@@ -692,7 +692,7 @@ variables {
                     }
                 })
             })
-        )
+        );
     }
 
     #[test]
@@ -713,7 +713,7 @@ variables
         assert_eq!(
             error,
             Error::new(Pos::new(8, 10), false, ParseError::GraphQlVariables)
-        )
+        );
     }
 
     #[test]
@@ -738,6 +738,6 @@ variables [
         assert_eq!(
             error,
             Error::new(Pos::new(8, 11), false, ParseError::GraphQlVariables)
-        )
+        );
     }
 }
