@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,7 +15,6 @@
  * limitations under the License.
  *
  */
-
 use crate::ast::*;
 use crate::parser::combinators::*;
 use crate::parser::error::*;
@@ -23,7 +22,7 @@ use crate::parser::number::{integer, natural, number};
 use crate::parser::primitives::*;
 use crate::parser::reader::Reader;
 use crate::parser::string::*;
-use crate::parser::{expr, filename, ParseResult};
+use crate::parser::{expr, filename, filename_password, ParseResult};
 
 /// Parse an option in an `[Options]` section.
 pub fn parse(reader: &mut Reader) -> ParseResult<EntryOption> {
@@ -56,6 +55,9 @@ pub fn parse(reader: &mut Reader) -> ParseResult<EntryOption> {
         "location" => option_follow_location(reader)?,
         "location-trusted" => option_follow_location_trusted(reader)?,
         "max-redirs" => option_max_redirect(reader)?,
+        "netrc" => option_netrc(reader)?,
+        "netrc-file" => option_netrc_file(reader)?,
+        "netrc-optional" => option_netrc_optional(reader)?,
         "output" => option_output(reader)?,
         "path-as-is" => option_path_as_is(reader)?,
         "proxy" => option_proxy(reader)?,
@@ -64,6 +66,7 @@ pub fn parse(reader: &mut Reader) -> ParseResult<EntryOption> {
         "retry-interval" => option_retry_interval(reader)?,
         "skip" => option_skip(reader)?,
         "unix-socket" => option_unix_socket(reader)?,
+        "user" => option_user(reader)?,
         "variable" => option_variable(reader)?,
         "verbose" => option_verbose(reader)?,
         "very-verbose" => option_very_verbose(reader)?,
@@ -98,7 +101,7 @@ fn option_cacert(reader: &mut Reader) -> ParseResult<OptionKind> {
 }
 
 fn option_cert(reader: &mut Reader) -> ParseResult<OptionKind> {
-    let value = filename::parse(reader)?;
+    let value = filename_password::parse(reader)?;
     Ok(OptionKind::ClientCert(value))
 }
 
@@ -172,6 +175,21 @@ fn option_max_redirect(reader: &mut Reader) -> ParseResult<OptionKind> {
     Ok(OptionKind::MaxRedirect(value))
 }
 
+fn option_netrc(reader: &mut Reader) -> ParseResult<OptionKind> {
+    let value = nonrecover(boolean_option, reader)?;
+    Ok(OptionKind::NetRc(value))
+}
+
+fn option_netrc_file(reader: &mut Reader) -> ParseResult<OptionKind> {
+    let value = unquoted_template(reader)?;
+    Ok(OptionKind::NetRcFile(value))
+}
+
+fn option_netrc_optional(reader: &mut Reader) -> ParseResult<OptionKind> {
+    let value = nonrecover(boolean_option, reader)?;
+    Ok(OptionKind::NetRcOptional(value))
+}
+
 fn option_output(reader: &mut Reader) -> ParseResult<OptionKind> {
     let value = filename::parse(reader)?;
     Ok(OptionKind::Output(value))
@@ -207,6 +225,11 @@ fn option_skip(reader: &mut Reader) -> ParseResult<OptionKind> {
     Ok(OptionKind::Skip(value))
 }
 
+fn option_user(reader: &mut Reader) -> ParseResult<OptionKind> {
+    let value = unquoted_template(reader)?;
+    Ok(OptionKind::User(value))
+}
+
 fn option_unix_socket(reader: &mut Reader) -> ParseResult<OptionKind> {
     let value = unquoted_template(reader)?;
     Ok(OptionKind::UnixSocket(value))
@@ -433,7 +456,7 @@ mod tests {
     fn test_option_insecure_error() {
         let mut reader = Reader::new("insecure: error");
         let error = parse(&mut reader).err().unwrap();
-        assert!(!error.recoverable)
+        assert!(!error.recoverable);
     }
 
     #[test]
@@ -516,7 +539,7 @@ mod tests {
     fn test_option_cacert_error() {
         let mut reader = Reader::new("cacert: ###");
         let error = parse(&mut reader).err().unwrap();
-        assert!(!error.recoverable)
+        assert!(!error.recoverable);
     }
 
     #[test]
