@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -137,7 +137,7 @@ fn version(reader: &mut Reader) -> ParseResult<Version> {
     let next_c = reader.peek();
     match next_c {
         Some('/') => {
-            let available_version = vec![
+            let available_version = [
                 ("/1.0", VersionValue::Version1),
                 ("/1.1", VersionValue::Version11),
                 ("/2", VersionValue::Version2),
@@ -154,7 +154,7 @@ fn version(reader: &mut Reader) -> ParseResult<Version> {
             }
             Err(Error::new(start.pos, false, ParseError::Version))
         }
-        Some(' ') => Ok(Version {
+        Some(' ') | Some('\t') => Ok(Version {
             value: VersionAny,
             source_info: SourceInfo::new(start.pos, reader.state.pos),
         }),
@@ -480,6 +480,20 @@ mod tests {
 
     #[test]
     fn test_version() {
+        let mut reader = Reader::new("HTTP 200");
+        assert_eq!(
+            version(&mut reader).unwrap().value,
+            VersionValue::VersionAny
+        );
+        assert_eq!(reader.state.cursor, 4);
+
+        let mut reader = Reader::new("HTTP\t200");
+        assert_eq!(
+            version(&mut reader).unwrap().value,
+            VersionValue::VersionAny
+        );
+        assert_eq!(reader.state.cursor, 4);
+
         let mut reader = Reader::new("HTTP/1.1 200");
         assert_eq!(version(&mut reader).unwrap().value, VersionValue::Version11);
 
