@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -87,8 +87,10 @@ fn predicate_func_value(reader: &mut Reader) -> ParseResult<PredicateFuncValue>
             string_predicate,
             collection_predicate,
             date_predicate,
+            iso_date_predicate,
             exist_predicate,
             is_empty_predicate,
+            is_number_predicate,
         ],
         reader,
     ) {
@@ -325,6 +327,11 @@ fn date_predicate(reader: &mut Reader) -> ParseResult<PredicateFuncValue> {
     Ok(PredicateFuncValue::IsDate)
 }
 
+fn iso_date_predicate(reader: &mut Reader) -> ParseResult<PredicateFuncValue> {
+    try_literal("isIsoDate", reader)?;
+    Ok(PredicateFuncValue::IsIsoDate)
+}
+
 fn exist_predicate(reader: &mut Reader) -> ParseResult<PredicateFuncValue> {
     try_literal("exists", reader)?;
     Ok(PredicateFuncValue::Exist)
@@ -335,6 +342,11 @@ fn is_empty_predicate(reader: &mut Reader) -> ParseResult<PredicateFuncValue> {
     Ok(PredicateFuncValue::IsEmpty)
 }
 
+fn is_number_predicate(reader: &mut Reader) -> ParseResult<PredicateFuncValue> {
+    try_literal("isNumber", reader)?;
+    Ok(PredicateFuncValue::IsNumber)
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
