@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -105,7 +105,7 @@ impl Reader {
                 None => return s,
                 Some(c) => {
                     if predicate(&c) {
-                        s.push(self.read().unwrap())
+                        s.push(self.read().unwrap());
                     } else {
                         return s;
                     }
@@ -124,12 +124,12 @@ impl Reader {
                 Some(c) => {
                     if escaped && c == ' ' {
                         escaped = false;
-                        s.push(self.read().unwrap())
+                        s.push(self.read().unwrap());
                     } else if c == '\\' {
                         escaped = true;
                         let _backslash = self.read().unwrap();
                     } else if predicate(&c) {
-                        s.push(self.read().unwrap())
+                        s.push(self.read().unwrap());
                     } else {
                         return s;
                     }
