@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -37,7 +37,7 @@ pub fn make_logger_parser_error(
     filename: Option<PathBuf>,
 ) -> impl Fn(&parser::Error, bool) {
     move |error: &parser::Error, warning: bool| {
-        log_error(lines.clone(), color, filename.clone(), error, warning)
+        log_error(lines.clone(), color, filename.clone(), error, warning);
     }
 }
 
@@ -47,7 +47,7 @@ pub fn make_logger_linter_error(
     filename: Option<PathBuf>,
 ) -> impl Fn(&linter::Error, bool) {
     move |error: &linter::Error, warning: bool| {
-        log_error(lines.clone(), color, filename.clone(), error, warning)
+        log_error(lines.clone(), color, filename.clone(), error, warning);
     }
 }
 
