@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -99,7 +99,7 @@ impl ToJson for Response {
     fn to_json(&self) -> JValue {
         let mut attributes = vec![];
         if let Some(v) = get_json_version(&self.version.value) {
-            attributes.push(("version".to_string(), JValue::String(v)))
+            attributes.push(("version".to_string(), JValue::String(v)));
         }
         if let StatusValue::Specific(n) = self.status.value {
             attributes.push(("status".to_string(), JValue::Number(n.to_string())));
@@ -120,10 +120,10 @@ impl ToJson for Response {
     }
 }
 
-fn add_headers(attributes: &mut Vec<(String, JValue)>, headers: &Vec<Header>) {
+fn add_headers(attributes: &mut Vec<(String, JValue)>, headers: &[Header]) {
     if !headers.is_empty() {
         let headers = JValue::List(headers.iter().map(|h| h.to_json()).collect());
-        attributes.push(("headers".to_string(), headers))
+        attributes.push(("headers".to_string(), headers));
     }
 }
 
@@ -297,6 +297,9 @@ impl ToJson for EntryOption {
             OptionKind::IpV4(value) => value.to_json(),
             OptionKind::IpV6(value) => value.to_json(),
             OptionKind::MaxRedirect(value) => value.to_json(),
+            OptionKind::NetRc(value) => value.to_json(),
+            OptionKind::NetRcFile(filename) => JValue::String(filename.to_string()),
+            OptionKind::NetRcOptional(value) => value.to_json(),
             OptionKind::Output(filename) => JValue::String(filename.to_string()),
             OptionKind::PathAsIs(value) => value.to_json(),
             OptionKind::Proxy(value) => JValue::String(value.to_string()),
@@ -305,6 +308,7 @@ impl ToJson for EntryOption {
             OptionKind::RetryInterval(value) => value.to_json(),
             OptionKind::Skip(value) => value.to_json(),
             OptionKind::UnixSocket(value) => JValue::String(value.to_string()),
+            OptionKind::User(value) => JValue::String(value.to_string()),
             OptionKind::Variable(value) => {
                 JValue::String(format!("{}={}", value.name, value.value))
             }
@@ -485,7 +489,7 @@ impl ToJson for Predicate {
     fn to_json(&self) -> JValue {
         let mut attributes = vec![];
         if self.not {
-            attributes.push(("not".to_string(), JValue::Boolean(true)))
+            attributes.push(("not".to_string(), JValue::Boolean(true)));
         }
         match self.predicate_func.value.clone() {
             PredicateFuncValue::Equal { value, .. } => {
@@ -559,12 +563,18 @@ impl ToJson for Predicate {
             PredicateFuncValue::IsDate => {
                 attributes.push(("type".to_string(), JValue::String("isDate".to_string())));
             }
+            PredicateFuncValue::IsIsoDate => {
+                attributes.push(("type".to_string(), JValue::String("isIsoDate".to_string())));
+            }
             PredicateFuncValue::Exist => {
                 attributes.push(("type".to_string(), JValue::String("exist".to_string())));
             }
             PredicateFuncValue::IsEmpty => {
                 attributes.push(("type".to_string(), JValue::String("isEmpty".to_string())));
             }
+            PredicateFuncValue::IsNumber => {
+                attributes.push(("type".to_string(), JValue::String("isNumber".to_string())));
+            }
         }
         JValue::Object(attributes)
     }
