@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -121,7 +121,7 @@ impl Tokenizable for Response {
         tokens.append(&mut self.headers.iter().flat_map(|e| e.tokenize()).collect());
         tokens.append(&mut self.sections.iter().flat_map(|e| e.tokenize()).collect());
         if let Some(body) = self.clone().body {
-            tokens.append(&mut body.tokenize())
+            tokens.append(&mut body.tokenize());
         }
         tokens
     }
@@ -207,7 +207,7 @@ impl Tokenizable for SectionValue {
             }
             SectionValue::BasicAuth(item) => {
                 if let Some(kv) = item {
-                    tokens.append(&mut kv.tokenize())
+                    tokens.append(&mut kv.tokenize());
                 }
             }
             SectionValue::FormParams(items) => {
@@ -495,7 +495,11 @@ impl Tokenizable for CertificateAttributeName {
             CertificateAttributeName::ExpireDate => "Expire-Date",
             CertificateAttributeName::SerialNumber => "Serial-Number",
         };
-        vec![Token::String(value.to_string())]
+        vec![
+            Token::StringDelimiter("\"".to_string()),
+            Token::String(value.to_string()),
+            Token::StringDelimiter("\"".to_string()),
+        ]
     }
 }
 
@@ -595,12 +599,18 @@ impl Tokenizable for PredicateFuncValue {
             PredicateFuncValue::IsDate => {
                 tokens.push(Token::PredicateType(self.name()));
             }
+            PredicateFuncValue::IsIsoDate => {
+                tokens.push(Token::PredicateType(self.name()));
+            }
             PredicateFuncValue::Exist => {
                 tokens.push(Token::PredicateType(self.name()));
             }
             PredicateFuncValue::IsEmpty => {
                 tokens.push(Token::PredicateType(self.name()));
             }
+            PredicateFuncValue::IsNumber => {
+                tokens.push(Token::PredicateType(self.name()));
+            }
         }
         tokens
     }
@@ -703,7 +713,7 @@ impl Tokenizable for Template {
         if let Some(d) = self.delimiter {
             tokens.push(Token::StringDelimiter(d.to_string()));
         }
-        for element in self.elements.clone() {
+        for element in &self.elements {
             tokens.append(&mut element.tokenize());
         }
         if let Some(d) = self.delimiter {
@@ -886,6 +896,9 @@ impl Tokenizable for OptionKind {
             OptionKind::IpV4(value) => value.tokenize(),
             OptionKind::IpV6(value) => value.tokenize(),
             OptionKind::MaxRedirect(value) => value.tokenize(),
+            OptionKind::NetRc(value) => value.tokenize(),
+            OptionKind::NetRcFile(filename) => filename.tokenize(),
+            OptionKind::NetRcOptional(value) => value.tokenize(),
             OptionKind::Output(filename) => filename.tokenize(),
             OptionKind::PathAsIs(value) => value.tokenize(),
             OptionKind::Proxy(value) => value.tokenize(),
@@ -894,6 +907,7 @@ impl Tokenizable for OptionKind {
             OptionKind::RetryInterval(value) => value.tokenize(),
             OptionKind::Skip(value) => value.tokenize(),
             OptionKind::UnixSocket(value) => value.tokenize(),
+            OptionKind::User(value) => value.tokenize(),
             OptionKind::Variable(value) => value.tokenize(),
             OptionKind::Verbose(value) => value.tokenize(),
             OptionKind::VeryVerbose(value) => value.tokenize(),
