@@ -1,6 +1,6 @@
 /*
  * Hurl (https://hurl.dev)
- * Copyright (C) 2023 Orange
+ * Copyright (C) 2024 Orange
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -178,12 +178,12 @@ fn lint_section_value(section_value: &SectionValue) -> SectionValue {
 fn section_value_index(section_value: SectionValue) -> u32 {
     match section_value {
         // Request sections
-        SectionValue::QueryParams(_) => 0,
-        SectionValue::BasicAuth(_) => 1,
-        SectionValue::FormParams(_) => 2,
-        SectionValue::MultipartFormData(_) => 3,
-        SectionValue::Cookies(_) => 4,
-        SectionValue::Options(_) => 5,
+        SectionValue::Options(_) => 0,
+        SectionValue::QueryParams(_) => 1,
+        SectionValue::BasicAuth(_) => 2,
+        SectionValue::FormParams(_) => 3,
+        SectionValue::MultipartFormData(_) => 4,
+        SectionValue::Cookies(_) => 5,
         // Response sections
         SectionValue::Captures(_) => 0,
         SectionValue::Asserts(_) => 1,
@@ -396,8 +396,10 @@ fn lint_predicate_func_value(predicate_func_value: &PredicateFuncValue) -> Predi
         PredicateFuncValue::IsString => PredicateFuncValue::IsString,
         PredicateFuncValue::IsCollection => PredicateFuncValue::IsCollection,
         PredicateFuncValue::IsDate => PredicateFuncValue::IsDate,
+        PredicateFuncValue::IsIsoDate => PredicateFuncValue::IsIsoDate,
         PredicateFuncValue::Exist => PredicateFuncValue::Exist,
         PredicateFuncValue::IsEmpty => PredicateFuncValue::IsEmpty,
+        PredicateFuncValue::IsNumber => PredicateFuncValue::IsNumber,
     }
 }
 
